@@ -1,6 +1,6 @@
 /*
     license
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
 #include "license.h"
-#include <gdk/gdkkeysyms.h>
+#include "misc.h"
 
 
 /******************************************************************************
@@ -72,26 +72,6 @@ license_dialog_timeout (LicenseDlg *ld)
 }
 
 
-/* ja:ダイアログが破棄されるとき */
-static void
-license_dialog_destroy (GtkWidget  *widget,
-                        LicenseDlg *ld)
-{
-}
-
-
-/* ja:ESCが押された */
-static gboolean
-license_dialog_key_press (GtkWidget   *widget,
-                          GdkEventKey *event,
-                          gpointer     user_data)
-{
-  if (event->keyval == GDK_Escape)
-    gtk_dialog_response (GTK_DIALOG (widget), GTK_RESPONSE_NONE);
-  return FALSE;
-}
-
-
 /*  ja:ライセンス表示
     text:ライセンス
      RET,ハッシュ値(ライセンス同意),-1:ライセンス拒否                       */
@@ -100,8 +80,9 @@ license_dialog (const gchar *text)
 {
   gboolean result;
   guint timer_id;
+  GtkRequisition req0, req1;
   GtkTextBuffer *buffer;
-  GtkWidget *dialog, *hbox, *vbox, *scroll;
+  GtkWidget *dialog, *vbox, *scroll, *fixed;
   LicenseDlg ld;
 
   if (!text)
@@ -118,9 +99,7 @@ license_dialog (const gchar *text)
   gtk_window_set_default_size (GTK_WINDOW (dialog),
                                             0, gdk_screen_height () * 2 / 3);
   g_signal_connect_after (G_OBJECT (dialog), "key-press-event",
-                                G_CALLBACK (license_dialog_key_press), NULL);
-  g_signal_connect (G_OBJECT (dialog), "destroy",
-                                G_CALLBACK (license_dialog_destroy), &ld);
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
   /* ja:テキスト */
   ld.textview = gtk_text_view_new ();
   buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (ld.textview));
@@ -138,20 +117,25 @@ license_dialog (const gchar *text)
   ld.radio1 = gtk_radio_button_new_with_label_from_widget
                                 (GTK_RADIO_BUTTON (ld.radio0), _("I deny."));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (ld.radio1), TRUE);
+  /* ja:フィクスト */
+  gtk_widget_size_request (ld.radio0, &req0);
+  gtk_widget_size_request (ld.radio1, &req1);
+  fixed = gtk_fixed_new ();
+  gtk_widget_set_size_request (fixed, req0.width + req1.width + SPACING,
+                                      MAX (req0.height, req1.height));
+  gtk_fixed_put (GTK_FIXED (fixed), ld.radio0, 0, 0);
+  gtk_fixed_put (GTK_FIXED (fixed), ld.radio1, req0.width + SPACING, 0);
   /* ja:フレームとボックス */
   vbox = gtk_vbox_new (FALSE, SPACING);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), SPACING);
   gtk_box_pack_start (GTK_BOX (vbox), scroll, TRUE, TRUE, 0);
-  hbox = gtk_hbox_new (FALSE, SPACING);
-  gtk_box_pack_start (GTK_BOX (hbox), ld.radio0, FALSE, FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (hbox), ld.radio1, FALSE, FALSE, 0);
-  gtk_box_pack_end (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
+  gtk_box_pack_end (GTK_BOX (vbox), fixed, FALSE, FALSE, 0);
   gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), vbox);
 
   /* ja:表示 */
   gtk_widget_show (scroll);
   gtk_widget_show (ld.textview);
-  gtk_widget_show (hbox);
+  gtk_widget_show (fixed);
   gtk_widget_show (vbox);
 
   timer_id = g_timeout_add (100, (GSourceFunc)license_dialog_timeout, &ld);
@@ -164,8 +148,8 @@ license_dialog (const gchar *text)
 #endif /* USE_THREAD */
   g_source_remove (timer_id);
   g_free (ld.display);
-  result = result
-            && gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (ld.radio0));
+  if (result)
+    result = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (ld.radio0));
   gtk_widget_destroy (dialog);
 
   return result ? ABS ((gint)g_str_hash (text)) : -1;
