@@ -1,6 +1,6 @@
 /*
     Profile
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -345,14 +345,14 @@ profile_get_size (Profile     *profile,
   switch (type)
     {
       case PROFILE_VALUE_TYPE_BOOL:
-        return g_strcasecmp (p->value, "true") == 0
-                || g_strcasecmp (p->value, "false") == 0
-                || g_strcasecmp (p->value, "yes") == 0
-                || g_strcasecmp (p->value, "no") == 0
-                || g_strcasecmp (p->value, "on") == 0
-                || g_strcasecmp (p->value, "off") == 0
-                || g_strcasecmp (p->value, "ok") == 0
-                || g_strcasecmp (p->value, "cancel") == 0
+        return g_ascii_strcasecmp (p->value, "true") == 0
+                || g_ascii_strcasecmp (p->value, "false") == 0
+                || g_ascii_strcasecmp (p->value, "yes") == 0
+                || g_ascii_strcasecmp (p->value, "no") == 0
+                || g_ascii_strcasecmp (p->value, "on") == 0
+                || g_ascii_strcasecmp (p->value, "off") == 0
+                || g_ascii_strcasecmp (p->value, "ok") == 0
+                || g_ascii_strcasecmp (p->value, "cancel") == 0
                 ? sizeof (gboolean) : 0;
       case PROFILE_VALUE_TYPE_INT:
         return sizeof (gint);
@@ -407,15 +407,15 @@ profile_get_value (Profile     *profile,
       case PROFILE_VALUE_TYPE_BOOL:
         if (size < sizeof (gboolean))
           return FALSE;
-        if (g_strcasecmp (p->value, "true") == 0
-            || g_strcasecmp (p->value, "yes") == 0
-            || g_strcasecmp (p->value, "on") == 0
-            || g_strcasecmp (p->value, "ok") == 0)
+        if (g_ascii_strcasecmp (p->value, "true") == 0
+            || g_ascii_strcasecmp (p->value, "yes") == 0
+            || g_ascii_strcasecmp (p->value, "on") == 0
+            || g_ascii_strcasecmp (p->value, "ok") == 0)
           *((gboolean *)value) = TRUE;
-        else if (g_strcmp (p->value, "false") == 0
-            || g_strcasecmp (p->value, "no") == 0
-            || g_strcasecmp (p->value, "off") == 0
-            || g_strcasecmp (p->value, "cancel") == 0)
+        else if (g_ascii_strcasecmp (p->value, "false") == 0
+            || g_ascii_strcasecmp (p->value, "no") == 0
+            || g_ascii_strcasecmp (p->value, "off") == 0
+            || g_ascii_strcasecmp (p->value, "cancel") == 0)
           *((gboolean *)value) = FALSE;
         else
           return FALSE;
