@@ -1,6 +1,6 @@
 /*
     orzcharlist
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
 #include "misc/charuty.h"
 #include "orzcharlist.h"
@@ -111,15 +111,22 @@ static void
 orz_charlist_changed (GtkTreeSelection *select,
                       OrzCharlist      *charlist)
 {
-  gint count, pos = -1;
+  gint i, pos = -1;
   GtkTreeIter iter;
+  GtkTreeModel *model;
 
-  for (count = 0; gtk_tree_model_iter_nth_child
-            (GTK_TREE_MODEL (charlist->store), &iter, NULL, count); count++)
+  model = gtk_tree_view_get_model (GTK_TREE_VIEW (charlist->tview));
+  for (i = 0; gtk_tree_model_iter_nth_child (model, &iter, NULL, i); i++)
     if (gtk_tree_selection_iter_is_selected (select, &iter))
-      pos = count;
+      {
+        pos = i;
+        break;
+      }
   if (pos >= 0)
     {
+      gint count;
+
+      count = gtk_tree_model_iter_n_children (model, NULL);
       gtk_widget_set_sensitive (charlist->remove_button, count > 1);
       gtk_widget_set_sensitive (charlist->up_button, pos > 0);
       gtk_widget_set_sensitive (charlist->down_button, pos < count - 1);
@@ -133,27 +140,32 @@ orz_charlist_changed (GtkTreeSelection *select,
 }
 
 
-/* ja:新規 */
+/* ja:追加 */
 static void
-orz_charlist_clicked_new (GtkWidget   *widget,
+orz_charlist_clicked_add (GtkWidget   *widget,
                           OrzCharlist *charlist)
 {
   gchar *charset;
   gint i;
+  GtkListStore *store;
   GtkTreeIter iter;
+  GtkTreeSelection *select;
 
+  store = GTK_LIST_STORE (gtk_tree_view_get_model
+                                            (GTK_TREE_VIEW (charlist->tview)));
+  select = gtk_tree_view_get_selection (GTK_TREE_VIEW (charlist->tview));
   /* ja:挿入 */
   charset = orz_charset_get_charset (ORZ_CHARSET (charlist->charset));
-  for (i = 0; gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (charlist->store),
+  for (i = 0; gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (store),
                                                         &iter, NULL, i); i++)
-    if (gtk_tree_selection_iter_is_selected (charlist->select, &iter))
+    if (gtk_tree_selection_iter_is_selected (select, &iter))
       {
         i++;
         break;
       }
-  gtk_list_store_insert (charlist->store, &iter, i);
-  gtk_list_store_set (charlist->store, &iter, 0, g_strdup (charset), -1);
-  gtk_tree_selection_select_iter (charlist->select, &iter);
+  gtk_list_store_insert (store, &iter, i);
+  gtk_list_store_set (store, &iter, 0, g_strdup (charset), -1);
+  gtk_tree_selection_select_iter (select, &iter);
   /* ja:コンボ */
   orz_charset_remove_candidate (ORZ_CHARSET (charlist->charset), charset);
   g_free (charset);
@@ -170,18 +182,22 @@ orz_charlist_clicked_remove (GtkWidget   *widget,
                              OrzCharlist *charlist)
 {
   gint i;
+  GtkListStore *store;
   GtkTreeIter iter;
+  GtkTreeSelection *select;
 
+  store = GTK_LIST_STORE (gtk_tree_view_get_model
+                                            (GTK_TREE_VIEW (charlist->tview)));
+  select = gtk_tree_view_get_selection (GTK_TREE_VIEW (charlist->tview));
   /* ja:削除 */
-  for (i = 0; gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (charlist->store),
+  for (i = 0; gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (store),
                                                         &iter, NULL, i); i++)
-    if (gtk_tree_selection_iter_is_selected (charlist->select, &iter))
+    if (gtk_tree_selection_iter_is_selected (select, &iter))
       {
         gchar *charset;
 
-        gtk_tree_model_get (GTK_TREE_MODEL (charlist->store),
-                                                    &iter, 0, &charset, -1);
-        gtk_list_store_remove (charlist->store, &iter);
+        gtk_tree_model_get (GTK_TREE_MODEL (store), &iter, 0, &charset, -1);
+        gtk_list_store_remove (store, &iter);
         /* ja:コンボ */
         orz_charset_add_candidate (ORZ_CHARSET (charlist->charset), charset);
         orz_charset_set_charset (ORZ_CHARSET (charlist->charset), charset);
@@ -199,24 +215,27 @@ orz_charlist_clicked_up (GtkWidget   *widget,
                          OrzCharlist *charlist)
 {
   gint i;
+  GtkListStore *store;
   GtkTreeIter iter0;
+  GtkTreeSelection *select;
 
-  for (i = 0; gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (charlist->store),
+  store = GTK_LIST_STORE (gtk_tree_view_get_model
+                                            (GTK_TREE_VIEW (charlist->tview)));
+  select = gtk_tree_view_get_selection (GTK_TREE_VIEW (charlist->tview));
+  for (i = 0; gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (store),
                                                         &iter0, NULL, i); i++)
-    if (gtk_tree_selection_iter_is_selected (charlist->select, &iter0))
+    if (gtk_tree_selection_iter_is_selected (select, &iter0))
       {
         gchar *charset0, *charset1;
         GtkTreeIter iter1;
 
-        gtk_tree_model_get (GTK_TREE_MODEL (charlist->store),
-                                                    &iter0, 0, &charset0, -1);
-        gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (charlist->store),
+        gtk_tree_model_get (GTK_TREE_MODEL (store), &iter0, 0, &charset0, -1);
+        gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (store),
                                                         &iter1, NULL, i - 1);
-        gtk_tree_model_get (GTK_TREE_MODEL (charlist->store),
-                                                    &iter1, 0, &charset1, -1);
-        gtk_list_store_set (charlist->store, &iter0, 0, charset1, -1);
-        gtk_list_store_set (charlist->store, &iter1, 0, charset0, -1);
-        gtk_tree_selection_select_iter (charlist->select, &iter1);
+        gtk_tree_model_get (GTK_TREE_MODEL (store), &iter1, 0, &charset1, -1);
+        gtk_list_store_set (store, &iter0, 0, charset1, -1);
+        gtk_list_store_set (store, &iter1, 0, charset0, -1);
+        gtk_tree_selection_select_iter (select, &iter1);
         g_free (charset0);
         g_free (charset1);
         break;
@@ -233,24 +252,27 @@ orz_charlist_clicked_down (GtkWidget   *widget,
                            OrzCharlist *charlist)
 {
   gint i;
+  GtkListStore *store;
   GtkTreeIter iter0;
+  GtkTreeSelection *select;
 
-  for (i = 0; gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (charlist->store),
+  store = GTK_LIST_STORE (gtk_tree_view_get_model
+                                            (GTK_TREE_VIEW (charlist->tview)));
+  select = gtk_tree_view_get_selection (GTK_TREE_VIEW (charlist->tview));
+  for (i = 0; gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (store),
                                                         &iter0, NULL, i); i++)
-    if (gtk_tree_selection_iter_is_selected (charlist->select, &iter0))
+    if (gtk_tree_selection_iter_is_selected (select, &iter0))
       {
         gchar *charset0, *charset1;
         GtkTreeIter iter1;
 
-        gtk_tree_model_get (GTK_TREE_MODEL (charlist->store),
-                                                    &iter0, 0, &charset0, -1);
-        gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (charlist->store),
+        gtk_tree_model_get (GTK_TREE_MODEL (store), &iter0, 0, &charset0, -1);
+        gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (store),
                                                         &iter1, NULL, i + 1);
-        gtk_tree_model_get (GTK_TREE_MODEL (charlist->store),
-                                                    &iter1, 0, &charset1, -1);
-        gtk_list_store_set (charlist->store, &iter0, 0, charset1, -1);
-        gtk_list_store_set (charlist->store, &iter1, 0, charset0, -1);
-        gtk_tree_selection_select_iter (charlist->select, &iter1);
+        gtk_tree_model_get (GTK_TREE_MODEL (store), &iter1, 0, &charset1, -1);
+        gtk_list_store_set (store, &iter0, 0, charset1, -1);
+        gtk_list_store_set (store, &iter1, 0, charset0, -1);
+        gtk_tree_selection_select_iter (select, &iter1);
         g_free (charset0);
         g_free (charset1);
         break;
@@ -267,7 +289,7 @@ orz_charlist_activate (GtkWidget   *widget,
                        OrzCharlist *charlist)
 {
   if (GTK_WIDGET_IS_SENSITIVE (charlist->ok_button))
-    orz_charlist_clicked_new (widget, charlist);
+    orz_charlist_clicked_add (widget, charlist);
 }
 
 
@@ -279,24 +301,24 @@ orz_charlist_edited (GtkWidget   *widget,
   const gchar *text;
   gint i;
   GtkTreeIter iter;
+  GtkTreeModel *model;
 
+  model = gtk_tree_view_get_model (GTK_TREE_VIEW (charlist->tview));
   text = orz_charset_get_charset (ORZ_CHARSET (widget));
-  for (i = 0; gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (charlist->store),
-                                                        &iter, NULL, i); i++)
+  for (i = 0; gtk_tree_model_iter_nth_child (model, &iter, NULL, i); i++)
     {
       gchar *charset;
 
-      gtk_tree_model_get (GTK_TREE_MODEL (charlist->store),
-                                                    &iter, 0, &charset, -1);
-      if (g_strcasecmp (charset, text) == 0)
+      gtk_tree_model_get (model, &iter, 0, &charset, -1);
+      if (g_ascii_strcasecmp (charset, text) == 0)
         {
-          gtk_widget_set_sensitive (charlist->new_button, FALSE);
+          gtk_widget_set_sensitive (charlist->add_button, FALSE);
           g_free (charset);
           return;
         }
       g_free (charset);
     }
-  gtk_widget_set_sensitive (charlist->new_button, charuty_is_valid (text));
+  gtk_widget_set_sensitive (charlist->add_button, charuty_is_valid (text));
 }
 
 
@@ -350,22 +372,20 @@ orz_charlist_init (OrzCharlist *charlist)
   g_signal_connect (G_OBJECT (charlist), "delete-event",
                                     G_CALLBACK (orz_charlist_delete), NULL);
   /* ja:ボタン */
-  charlist->ok_button = gtk_dialog_add_button (GTK_DIALOG (charlist),
-                                        GTK_STOCK_OK, GTK_RESPONSE_OK);
   charlist->cancel_button = gtk_dialog_add_button (GTK_DIALOG (charlist),
                                         GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
+  charlist->ok_button = gtk_dialog_add_button (GTK_DIALOG (charlist),
+                                        GTK_STOCK_OK, GTK_RESPONSE_OK);
   /* ja:リストボックス */
-  charlist->store = gtk_list_store_new (1, G_TYPE_STRING);
   charlist->tview = gtk_tree_view_new_with_model
-                                            (GTK_TREE_MODEL (charlist->store));
+                    (GTK_TREE_MODEL (gtk_list_store_new (1, G_TYPE_STRING)));
   gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (charlist->tview), FALSE);
   renderer = gtk_cell_renderer_text_new ();
   column = gtk_tree_view_column_new_with_attributes
             (_("Registered Character Encoding"), renderer, "text", 0, NULL);
   gtk_tree_view_append_column (GTK_TREE_VIEW (charlist->tview), column);
-  charlist->select = gtk_tree_view_get_selection
-                                            (GTK_TREE_VIEW (charlist->tview));
-  g_signal_connect (G_OBJECT (charlist->select),
+  g_signal_connect (G_OBJECT (gtk_tree_view_get_selection
+                                            (GTK_TREE_VIEW (charlist->tview))),
                     "changed", G_CALLBACK (orz_charlist_changed), charlist);
   /* en:Drag & Drop */
   gtk_tree_view_enable_model_drag_dest (GTK_TREE_VIEW (charlist->tview),
@@ -386,12 +406,12 @@ orz_charlist_init (OrzCharlist *charlist)
   g_signal_connect (G_OBJECT (charlist->charset), "edited",
                                 G_CALLBACK (orz_charlist_edited), charlist);
   /* ja:ボタン */
-  charlist->new_button = gtk_button_new_from_stock (GTK_STOCK_NEW);
-  charlist->remove_button = gtk_button_new_from_stock (GTK_STOCK_DELETE);
+  charlist->add_button = gtk_button_new_from_stock (GTK_STOCK_ADD);
+  charlist->remove_button = gtk_button_new_from_stock (GTK_STOCK_REMOVE);
   charlist->up_button = gtk_button_new_from_stock (GTK_STOCK_GO_UP);
   charlist->down_button = gtk_button_new_from_stock (GTK_STOCK_GO_DOWN);
-  g_signal_connect (G_OBJECT (charlist->new_button), "clicked",
-                        G_CALLBACK (orz_charlist_clicked_new), charlist);
+  g_signal_connect (G_OBJECT (charlist->add_button), "clicked",
+                        G_CALLBACK (orz_charlist_clicked_add), charlist);
   g_signal_connect (G_OBJECT (charlist->remove_button), "clicked",
                         G_CALLBACK (orz_charlist_clicked_remove), charlist);
   g_signal_connect (G_OBJECT (charlist->up_button), "clicked",
@@ -404,7 +424,7 @@ orz_charlist_init (OrzCharlist *charlist)
   gtk_box_pack_start (GTK_BOX (vbox), scroll, TRUE, TRUE, 0);
   gtk_box_pack_start (GTK_BOX (vbox), charlist->charset, FALSE, FALSE, 0);
   hbox = gtk_hbox_new (FALSE, SPACING);
-  gtk_box_pack_start (GTK_BOX (hbox), charlist->new_button, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (hbox), charlist->add_button, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (hbox),
                                     charlist->remove_button, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (hbox), charlist->up_button, FALSE, FALSE, 0);
@@ -413,7 +433,7 @@ orz_charlist_init (OrzCharlist *charlist)
   gtk_container_add (GTK_CONTAINER (GTK_DIALOG (charlist)->vbox), vbox);
 
   /* ja:表示 */
-  gtk_widget_set_sensitive (charlist->new_button, FALSE);
+  gtk_widget_set_sensitive (charlist->add_button, FALSE);
   gtk_widget_set_sensitive (charlist->remove_button, FALSE);
   gtk_widget_set_sensitive (charlist->up_button, FALSE);
   gtk_widget_set_sensitive (charlist->down_button, FALSE);
@@ -446,17 +466,17 @@ orz_charlist_get_charlist (OrzCharlist *charlist)
   gchar *list = NULL;
   gint i;
   GtkTreeIter iter;
+  GtkTreeModel *model;
 
   if (!charlist)
     return NULL;
-  for (i = 0; gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (charlist->store),
-                                                        &iter, NULL, i); i++)
+  model = gtk_tree_view_get_model (GTK_TREE_VIEW (charlist->tview));
+  for (i = 0; gtk_tree_model_iter_nth_child (model, &iter, NULL, i); i++)
     {
       gchar *charset, *tmp;
 
-      gtk_tree_model_get (GTK_TREE_MODEL (charlist->store),
-                                                    &iter, 0, &charset, -1);
-      tmp = list ? g_strjoin (",", list, charset, NULL) : g_strdup (charset);
+      gtk_tree_model_get (model, &iter, 0, &charset, -1);
+      tmp = list ? g_strconcat (list, ",", charset, NULL) : g_strdup (charset);
       g_free (charset);
       g_free (list);
       list = tmp;
@@ -475,18 +495,21 @@ orz_charlist_set_charlist (OrzCharlist *charlist,
   gboolean result = TRUE;
   gchar **charset;
   gint i;
+  GtkListStore *store;
 
   if (!charlist || !list)
     return FALSE;
-  gtk_list_store_clear (charlist->store);
+  store = GTK_LIST_STORE (gtk_tree_view_get_model
+                                            (GTK_TREE_VIEW (charlist->tview)));
+  gtk_list_store_clear (store);
   charset = g_strsplit (list, ",", 0);
   for (i = 0; charset[i]; i++)
     if (charuty_is_valid (charset[i]))
       {
         GtkTreeIter iter;
 
-        gtk_list_store_append (charlist->store, &iter);
-        gtk_list_store_set (charlist->store, &iter, 0, charset[i], -1);
+        gtk_list_store_append (store, &iter);
+        gtk_list_store_set (store, &iter, 0, charset[i], -1);
       }
     else
       {
@@ -544,9 +567,11 @@ orz_charlist_add_candidate (OrzCharlist *charlist,
   gboolean result = TRUE;
   gchar **charset;
   gint i;
+  GtkTreeModel *model;
 
   if (!charlist || !candidate)
     return FALSE;
+  model = gtk_tree_view_get_model (GTK_TREE_VIEW (charlist->tview));
   charset = g_strsplit (candidate, ",", 0);
   for (i = 0; charset[i]; i++)
     {
@@ -554,14 +579,12 @@ orz_charlist_add_candidate (OrzCharlist *charlist,
       gint j;
       GtkTreeIter iter;
 
-      for (j = 0; gtk_tree_model_iter_nth_child
-                    (GTK_TREE_MODEL (charlist->store), &iter, NULL, j); j++)
+      for (j = 0; gtk_tree_model_iter_nth_child (model, &iter, NULL, j); j++)
         {
           gchar *str;
 
-          gtk_tree_model_get (GTK_TREE_MODEL (charlist->store),
-                                                        &iter, 0, &str, -1);
-          if (g_strcasecmp (charset[i], str) == 0)
+          gtk_tree_model_get (model, &iter, 0, &str, -1);
+          if (g_ascii_strcasecmp (charset[i], str) == 0)
             exist = TRUE;
           g_free (str);
         }
