@@ -1,6 +1,6 @@
 /*
     orzcomm
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
 #include "misc/fileio.h"
 #include "orzcomm.h"
@@ -63,7 +63,7 @@ orz_comm_get_type (void)
 
   if (!type)
     {
-      static const GTypeInfo info =
+      const static GTypeInfo info =
       {
         sizeof (OrzCommClass),
         NULL,               /* base_init */
@@ -214,7 +214,7 @@ DdemlCallback (UINT     uType,
                   {
                     gchar **argv;
 
-                    argv = g_strsplit (text, "\n", G_MAXINT);
+                    argv = g_strsplit (text, "\n", 0);
                     g_signal_emit_by_name (G_OBJECT (comm), "recv", argv);
                     g_strfreev (argv);
                   }
@@ -293,7 +293,7 @@ orz_comm_selection_received (GtkWidget        *widget,
       gchar **argv;
 
       /* ja:他にプロセスのコマンドラインを受け取ったとき */
-      argv = g_strsplit (data->data, "\n", G_MAXINT);
+      argv = g_strsplit (data->data, "\n", 0);
       g_signal_emit_by_name (G_OBJECT (comm), "recv", argv);
       g_strfreev (argv);
     }
@@ -448,10 +448,10 @@ orz_comm_new (GtkWidget   *window,
      argv,引数
     files,TRUE:ファイル,FALSE:ファイルではない                              */
 void
-orz_comm_send_with_files (OrzComm   *comm,
-                          gint       argc,
-                          gchar    **argv,
-                          gboolean  *files)
+orz_comm_send_with_files (OrzComm         *comm,
+                          const gint       argc,
+                          gchar          **argv,
+                          const gboolean  *files)
 {
   gsize length = 0;
   gchar *arg = NULL, *tmp;
