@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -33,7 +33,6 @@
 #include "valchr.h"
 #include "version.h"
 #include "misc/fileio.h"
-#include "misc/misc.h"
 #include "orz/orzconf.h"
 #include "orz/orzhistory.h"
 #include "orz/orzmdi.h"
@@ -66,95 +65,169 @@ command_open (GtkWidget *widget,
   gint i;
 #endif /* GTK_CHECK_VERSION(2,4,0) || defined (G_OS_WIN32) */
 #ifdef G_OS_WIN32
-  gchar *filter = NULL;
-  gint length, pos = 0;
+  gint pos = 0;
+# if ! GLIB_CHECK_VERSION(2,6,0)
+#  ifdef UNICODE
+  gchar *utf8file;
+#  endif /* UNICODE */
   LPTSTR lpszPath, lpszFilter;
   OPENFILENAME ofn;
   TCHAR szFile[MAX_PATH];
-# ifdef UNICODE
-  gchar *utf8file;
+# endif /* not GLIB_CHECK_VERSION(2,6,0) */
 
-  utf8file = g_filename_to_utf8 (open_path, -1, NULL, NULL, NULL);
-  if (utf8file)
+# if GLIB_CHECK_VERSION(2,6,0)
+  if (G_WIN32_HAVE_WIDECHAR_API ())
     {
-      lpszPath = g_utf8_to_utf16 (utf8file, -1, NULL, NULL, NULL);
-      g_free (utf8file);
+      gchar *utf8file;
+      LPWSTR lpszPath, lpszFilter = NULL;
+      OPENFILENAMEW ofn;
+      WCHAR szFile[MAX_PATH];
+# endif /* GLIB_CHECK_VERSION(2,6,0) */
+
+# if GLIB_CHECK_VERSION(2,6,0) || defined (UNICODE)
+      utf8file = open_path
+                ? g_filename_to_utf8 (open_path, -1, NULL, NULL, NULL) : NULL;
+      if (utf8file)
+        {
+          lpszPath = g_utf8_to_utf16 (utf8file, -1, NULL, NULL, NULL);
+          g_free (utf8file);
+        }
+      else
+        {
+          lpszPath = NULL;
+        }
+      /* ja:フィルタの設定 */
+      for (i = 0; i < ftnum; i++)
+        {
+          gint length;
+          gunichar2 *utf16str;
+
+          utf16str = g_utf8_to_utf16 (ftype[i].text, -1, NULL, NULL, NULL);
+          length = lstrlenW (utf16str) + 1;
+          lpszFilter = g_realloc (lpszFilter, (pos + length + 1)
+                                                            * sizeof (WCHAR));
+          g_memmove (lpszFilter + pos, utf16str, length * sizeof (WCHAR));
+          g_free (utf16str);
+          pos += length;
+          utf16str = g_utf8_to_utf16 (ftype[i].ext, -1, NULL, NULL, NULL);
+          length = lstrlenW (utf16str) + 1;
+          lpszFilter = g_realloc (lpszFilter, (pos + length + 1)
+                                                            * sizeof (WCHAR));
+          g_memmove (lpszFilter + pos, utf16str, length * sizeof (WCHAR));
+          g_free (utf16str);
+          pos += length;
+        }
+      lpszFilter[pos] = '\0';
+      szFile[0] = '\0';
+      ofn.lStructSize = sizeof (OPENFILENAMEW);
+      ofn.hwndOwner = GDK_WINDOW_HWND (window->window);
+      ofn.lpstrFilter = lpszFilter;
+      ofn.nFilterIndex = findex - 1;
+      ofn.lpstrCustomFilter = NULL;
+      ofn.lpstrFile = szFile;
+      ofn.nMaxFile = MAX_PATH;
+      ofn.lpstrFileTitle = NULL;
+      ofn.lpstrInitialDir = lpszPath;
+      ofn.lpstrTitle = NULL;
+      ofn.Flags = OFN_HIDEREADONLY | OFN_NOCHANGEDIR;
+      ofn.lpstrDefExt = NULL;
+      if (GetOpenFileNameW (&ofn))
+        {
+          utf8file = g_utf16_to_utf8 (szFile, -1, NULL, NULL, NULL);
+          if (utf8file)
+            {
+              file = g_filename_from_utf8 (utf8file, -1, NULL, NULL, NULL);
+              g_free (utf8file);
+            }
+          findex = ofn.nFilterIndex - 1;
+        }
+      g_free (lpszPath);
+      g_free (lpszFilter);
+# endif /* GLIB_CHECK_VERSION(2,6,0) || defined (UNICODE) */
+# if GLIB_CHECK_VERSION(2,6,0)
     }
   else
     {
-      lpszPath = NULL;
-    }
-# else /* not UNICODE */
-#  if GTK_CHECK_VERSION(2,8,0)
-  lpszPath = g_win32_locale_filename_from_utf8 (open_path);
-#  elif GTK_CHECK_VERSION(2,6,0)
-  lpszPath = g_locale_from_utf8 (open_path, -1, NULL, NULL, NULL);
-#  else /* not GTK_CHECK_VERSION(2,6,0) */
-  lpszPath = g_strdup (open_path);
-#  endif /* not GTK_CHECK_VERSION(2,6,0) */
-# endif /* not UNICODE */
-  /* ja:フィルタの設定 */
-  for (i = 0; i < ftnum; i++)
-    {
-      length = g_strlen (ftype[i].text) + 1;
-      filter = g_realloc (filter, (pos + length + 1) * sizeof (gchar));
-      g_memmove (filter + pos, ftype[i].text, length * sizeof (gchar));
-      pos += length;
-      length = g_strlen (ftype[i].ext) + 1;
-      filter = g_realloc (filter, (pos + length + 1) * sizeof (gchar));
-      g_memmove (filter + pos, ftype[i].ext, length * sizeof (gchar));
-      pos += length;
-    }
-  filter[pos] = '\0';
-# ifdef UNICODE
-  lpszFilter = g_utf8_to_utf16 (filter, pos + 1, NULL, NULL, NULL);
-# else /* not UNICODE */
-  lpszFilter = g_locale_from_utf8 (filter, pos + 1, NULL, NULL, NULL);
-# endif /* not UNICODE */
-  g_free (filter);
-  szFile[0] = '\0';
-  ofn.lStructSize = sizeof (OPENFILENAME);
-  ofn.hwndOwner = GDK_WINDOW_HWND (window->window);
-  ofn.lpstrFilter = lpszFilter;
-  ofn.nFilterIndex = findex - 1;
-  ofn.lpstrCustomFilter = NULL;
-  ofn.lpstrFile = szFile;
-  ofn.nMaxFile = MAX_PATH;
-  ofn.lpstrFileTitle = NULL;
-  ofn.lpstrInitialDir = lpszPath;
-  ofn.lpstrTitle = NULL;
-  ofn.Flags = OFN_HIDEREADONLY | OFN_NOCHANGEDIR;
-  ofn.lpstrDefExt = NULL;
-  if (GetOpenFileName (&ofn))
-# ifdef UNICODE
-    {
-      utf8file = g_utf16_to_utf8 (szFile, -1, NULL, NULL, NULL);
-      if (utf8file)
-        {
-          file = g_filename_from_utf8 (utf8file, -1, NULL, NULL, NULL);
-          g_free (utf8file);
-        }
-      findex = ofn.nFilterIndex - 1;
-    }
-# else /* not UNICODE */
-#  if GTK_CHECK_VERSION(2,6,0)
-    file = g_locale_to_utf8 (szFile, -1, NULL, NULL, NULL);
-#  else /* not GTK_CHECK_VERSION(2,6,0) */
-    file = g_strdup (szFile);
-#  endif /* not GTK_CHECK_VERSION(2,6,0) */
-# endif /* not UNICODE */
-  g_free (lpszPath);
-  g_free (lpszFilter);
-#else /* not G_OS_WIN32 */
-  GtkWidget *dialog;
+      LPSTR lpszPath, lpszFilter = NULL;
+      OPENFILENAMEA ofn;
+      CHAR szFile[MAX_PATH];
+# endif /* GLIB_CHECK_VERSION(2,6,0) */
 
+# if GLIB_CHECK_VERSION(2,6,0) || ! defined (UNICODE)
+      lpszPath = open_path
+#  if GTK_CHECK_VERSION(2,8,0)
+                        ? g_win32_locale_filename_from_utf8 (open_path)
+#  elif GTK_CHECK_VERSION(2,6,0)
+                        ? g_locale_from_utf8 (open_path, -1, NULL, NULL, NULL)
+#  else /* not GTK_CHECK_VERSION(2,6,0) */
+                        ? g_strdup (open_path)
+#  endif /* not GTK_CHECK_VERSION(2,6,0) */
+                        : NULL;
+      /* ja:フィルタの設定 */
+      for (i = 0; i < ftnum; i++)
+        {
+          gint length;
+          gchar *str;
+
+          str = g_locale_from_utf8 (ftype[i].text, -1, NULL, NULL, NULL);
+          length = g_strlen (str) + 1;
+          lpszFilter = g_realloc (lpszFilter, (pos + length + 1)
+                                                            * sizeof (CHAR));
+          g_memmove (lpszFilter + pos, str, length * sizeof (CHAR));
+          g_free (str);
+          pos += length;
+          str = g_locale_from_utf8 (ftype[i].ext, -1, NULL, NULL, NULL);
+          length = g_strlen (str) + 1;
+          lpszFilter = g_realloc (lpszFilter, (pos + length + 1)
+                                                            * sizeof (CHAR));
+          g_memmove (lpszFilter + pos, str, length * sizeof (CHAR));
+          g_free (str);
+          pos += length;
+        }
+      lpszFilter[pos] = '\0';
+      szFile[0] = '\0';
+      ofn.lStructSize = sizeof (OPENFILENAMEA);
+      ofn.hwndOwner = GDK_WINDOW_HWND (window->window);
+      ofn.lpstrFilter = lpszFilter;
+      ofn.nFilterIndex = findex - 1;
+      ofn.lpstrCustomFilter = NULL;
+      ofn.lpstrFile = szFile;
+      ofn.nMaxFile = MAX_PATH;
+      ofn.lpstrFileTitle = NULL;
+      ofn.lpstrInitialDir = lpszPath;
+      ofn.lpstrTitle = NULL;
+      ofn.Flags = OFN_HIDEREADONLY | OFN_NOCHANGEDIR;
+      ofn.lpstrDefExt = NULL;
+      if (GetOpenFileNameA (&ofn))
+        {
+#  if GTK_CHECK_VERSION(2,6,0)
+          file = g_locale_to_utf8 (szFile, -1, NULL, NULL, NULL);
+#  else /* not GTK_CHECK_VERSION(2,6,0) */
+          file = g_strdup (szFile);
+#  endif /* not GTK_CHECK_VERSION(2,6,0) */
+          findex = ofn.nFilterIndex - 1;
+        }
+      g_free (lpszPath);
+      g_free (lpszFilter);
+# endif /* GLIB_CHECK_VERSION(2,6,0) || ! defined (UNICODE) */
+# if GLIB_CHECK_VERSION(2,6,0)
+    }
+# endif /* GLIB_CHECK_VERSION(2,6,0) */
+#else /* not G_OS_WIN32 */
+  gchar *title;
+  GtkStockItem stock_item;
+  GtkWidget *dialog;
 # if GTK_CHECK_VERSION(2,4,0)
   GtkFileFilter *filter;
+# endif /* GTK_CHECK_VERSION(2,4,0) */
 
-  dialog = gtk_file_chooser_dialog_new (_("Open"),
+  gtk_stock_lookup (GTK_STOCK_OPEN, &stock_item);
+  title = misc_mnemonic_to_text (stock_item.label);
+# if GTK_CHECK_VERSION(2,4,0)
+  dialog = gtk_file_chooser_dialog_new (title,
                         GTK_WINDOW (window), GTK_FILE_CHOOSER_ACTION_OPEN,
-                        GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
                         GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                        GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
                         NULL);
   if (open_path)
     gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dialog), open_path);
@@ -183,7 +256,7 @@ command_open (GtkWidget *widget,
                                                                 "user_data"));
     }
 # else /* not GTK_CHECK_VERSION(2,4,0) */
-  dialog = gtk_file_selection_new (_("Open"));
+  dialog = gtk_file_selection_new (title);
   if (open_path)
     {
       path = g_strconcat (open_path, G_SEARCHPATH_SEPARATOR_S, NULL);
@@ -195,6 +268,7 @@ command_open (GtkWidget *widget,
     file = g_strdup (gtk_file_selection_get_filename
                                                 (GTK_FILE_SELECTION (dialog)));
 # endif /* not GTK_CHECK_VERSION(2,4,0) */
+  g_free (title);
   gtk_widget_destroy (dialog);
 #endif /* not G_OS_WIN32 */
   if (file)
@@ -233,12 +307,18 @@ command_save (GtkWidget *widget,
           gchar *utf8str;
           GtkWidget *dialog;
 
+#if GLIB_CHECK_VERSION(2,6,0)
+          utf8str = g_filename_display_name (file);
+#else /* not GLIB_CHECK_VERSION(2,6,0) */
           utf8str = g_filename_to_utf8 (file, -1, NULL, NULL, NULL);
+#endif /* not GLIB_CHECK_VERSION(2,6,0) */
           dialog = gtk_message_dialog_new (GTK_WINDOW (window),
                     GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                     GTK_MESSAGE_INFO, GTK_BUTTONS_YES_NO,
                     _("%s\nThis file is existed.\n\nOver write?"), utf8str);
           g_free (utf8str);
+          g_signal_connect (G_OBJECT (dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
           result = gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_YES;
           gtk_widget_destroy (dialog);
         }
@@ -261,95 +341,169 @@ command_saveas (GtkWidget *widget,
   gint i;
 #endif /* GTK_CHECK_VERSION(2,4,0) || defined (G_OS_WIN32) */
 #ifdef G_OS_WIN32
-  gchar *filter = NULL;
-  gint length, pos = 0;
+  gint pos = 0;
+# if ! GLIB_CHECK_VERSION(2,6,0)
+#  ifdef UNICODE
+  gchar *utf8file;
+#  endif /* UNICODE */
   LPTSTR lpszPath, lpszFilter;
   OPENFILENAME ofn;
   TCHAR szFile[MAX_PATH];
-# ifdef UNICODE
-  gchar *utf8file;
+# endif /* not GLIB_CHECK_VERSION(2,6,0) */
 
-  utf8file = g_filename_to_utf8 (save_path, -1, NULL, NULL, NULL);
-  if (utf8file)
+# if GLIB_CHECK_VERSION(2,6,0)
+  if (G_WIN32_HAVE_WIDECHAR_API ())
     {
-      lpszPath = g_utf8_to_utf16 (utf8file, -1, NULL, NULL, NULL);
-      g_free (utf8file);
+      gchar *utf8file;
+      LPWSTR lpszPath, lpszFilter = NULL;
+      OPENFILENAMEW ofn;
+      WCHAR szFile[MAX_PATH];
+# endif /* GLIB_CHECK_VERSION(2,6,0) */
+
+# if GLIB_CHECK_VERSION(2,6,0) || defined (UNICODE)
+      utf8file = save_path
+                ? g_filename_to_utf8 (save_path, -1, NULL, NULL, NULL) : NULL;
+      if (utf8file)
+        {
+          lpszPath = g_utf8_to_utf16 (utf8file, -1, NULL, NULL, NULL);
+          g_free (utf8file);
+        }
+      else
+        {
+          lpszPath = NULL;
+        }
+      /* ja:フィルタの設定 */
+      for (i = 0; i < ftnum; i++)
+        {
+          gint length;
+          gunichar2 *utf16str;
+
+          utf16str = g_utf8_to_utf16 (ftype[i].text, -1, NULL, NULL, NULL);
+          length = lstrlenW (utf16str) + 1;
+          lpszFilter = g_realloc (lpszFilter, (pos + length + 1)
+                                                            * sizeof (WCHAR));
+          g_memmove (lpszFilter + pos, utf16str, length * sizeof (WCHAR));
+          g_free (utf16str);
+          pos += length;
+          utf16str = g_utf8_to_utf16 (ftype[i].ext, -1, NULL, NULL, NULL);
+          length = lstrlenW (utf16str) + 1;
+          lpszFilter = g_realloc (lpszFilter, (pos + length + 1)
+                                                            * sizeof (WCHAR));
+          g_memmove (lpszFilter + pos, utf16str, length * sizeof (WCHAR));
+          g_free (utf16str);
+          pos += length;
+        }
+      lpszFilter[pos] = '\0';
+      szFile[0] = '\0';
+      ofn.lStructSize = sizeof (OPENFILENAMEW);
+      ofn.hwndOwner = GDK_WINDOW_HWND (window->window);
+      ofn.lpstrFilter = lpszFilter;
+      ofn.nFilterIndex = findex - 1;
+      ofn.lpstrCustomFilter = NULL;
+      ofn.lpstrFile = szFile;
+      ofn.nMaxFile = MAX_PATH;
+      ofn.lpstrFileTitle = NULL;
+      ofn.lpstrInitialDir = lpszPath;
+      ofn.lpstrTitle = NULL;
+      ofn.Flags = OFN_HIDEREADONLY | OFN_NOCHANGEDIR | OFN_PATHMUSTEXIST;
+      ofn.lpstrDefExt = NULL;
+      if (GetSaveFileNameW (&ofn))
+        {
+          utf8file = g_utf16_to_utf8 (szFile, -1, NULL, NULL, NULL);
+          if (utf8file)
+            {
+              file = g_filename_from_utf8 (utf8file, -1, NULL, NULL, NULL);
+              g_free (utf8file);
+            }
+          findex = ofn.nFilterIndex - 1;
+        }
+      g_free (lpszPath);
+      g_free (lpszFilter);
+# endif /* GLIB_CHECK_VERSION(2,6,0) || defined (UNICODE) */
+# if GLIB_CHECK_VERSION(2,6,0)
     }
   else
     {
-      lpszPath = NULL;
-    }
-# else /* not UNICODE */
-#  if GTK_CHECK_VERSION(2,8,0)
-  lpszPath = g_win32_locale_filename_from_utf8 (save_path);
-#  elif GTK_CHECK_VERSION(2,6,0)
-  lpszPath = g_locale_from_utf8 (save_path, -1, NULL, NULL, NULL);
-#  else /* not GTK_CHECK_VERSION(2,6,0) */
-  lpszPath = g_strdup (save_path);
-#  endif /* not GTK_CHECK_VERSION(2,6,0) */
-# endif /* not UNICODE */
-  /* ja:フィルタの設定 */
-  for (i = 0; i < ftnum; i++)
-    {
-      length = g_strlen (ftype[i].text) + 1;
-      filter = g_realloc (filter, (pos + length + 1) * sizeof (gchar));
-      g_memmove (filter + pos, ftype[i].text, length * sizeof (gchar));
-      pos += length;
-      length = g_strlen (ftype[i].ext) + 1;
-      filter = g_realloc (filter, (pos + length + 1) * sizeof (gchar));
-      g_memmove (filter + pos, ftype[i].ext, length * sizeof (gchar));
-      pos += length;
-    }
-  filter[pos] = '\0';
-# ifdef UNICODE
-  lpszFilter = g_utf8_to_utf16 (filter, pos + 1, NULL, NULL, NULL);
-# else /* not UNICODE */
-  lpszFilter = g_locale_from_utf8 (filter, pos + 1, NULL, NULL, NULL);
-# endif /* not UNICODE */
-  g_free (filter);
-  szFile[0] = '\0';
-  ofn.lStructSize = sizeof (OPENFILENAME);
-  ofn.hwndOwner = GDK_WINDOW_HWND (window->window);
-  ofn.lpstrFilter = lpszFilter;
-  ofn.nFilterIndex = findex - 1;
-  ofn.lpstrCustomFilter = NULL;
-  ofn.lpstrFile = szFile;
-  ofn.nMaxFile = MAX_PATH;
-  ofn.lpstrFileTitle = NULL;
-  ofn.lpstrInitialDir = lpszPath;
-  ofn.lpstrTitle = NULL;
-  ofn.Flags = OFN_HIDEREADONLY | OFN_NOCHANGEDIR | OFN_PATHMUSTEXIST;
-  ofn.lpstrDefExt = NULL;
-  if (GetSaveFileName (&ofn))
-# ifdef UNICODE
-    {
-      utf16file = g_utf16_to_utf8 (szFile, -1, NULL, NULL, NULL);
-      if (utf16file)
-        {
-          file = g_filename_from_utf8 (utf16file, -1, NULL, NULL, NULL);
-          g_free (utf16file);
-        }
-      findex = ofn.nFilterIndex - 1;
-    }
-# else /* not UNICODE */
-#  if GTK_CHECK_VERSION(2,6,0)
-    file = g_locale_to_utf8 (szFile, -1, NULL, NULL, NULL);
-#  else /* not GTK_CHECK_VERSION(2,6,0) */
-    file = g_strdup (szFile);
-#  endif /* not GTK_CHECK_VERSION(2,6,0) */
-# endif /* not UNICODE */
-  g_free (lpszPath);
-  g_free (lpszFilter);
-#else /* not G_OS_WIN32 */
-  GtkWidget *dialog;
+      LPSTR lpszPath, lpszFilter = NULL;
+      OPENFILENAMEA ofn;
+      CHAR szFile[MAX_PATH];
+# endif /* GLIB_CHECK_VERSION(2,6,0) */
 
+# if GLIB_CHECK_VERSION(2,6,0) || ! defined (UNICODE)
+      lpszPath = save_path
+#  if GTK_CHECK_VERSION(2,8,0)
+                        ? g_win32_locale_filename_from_utf8 (save_path)
+#  elif GTK_CHECK_VERSION(2,6,0)
+                        ? g_locale_from_utf8 (save_path, -1, NULL, NULL, NULL)
+#  else /* not GTK_CHECK_VERSION(2,6,0) */
+                        ? g_strdup (save_path)
+#  endif /* not GTK_CHECK_VERSION(2,6,0) */
+                        : NULL;
+      /* ja:フィルタの設定 */
+      for (i = 0; i < ftnum; i++)
+        {
+          gint length;
+          gchar *str;
+
+          str = g_locale_from_utf8 (ftype[i].text, -1, NULL, NULL, NULL);
+          length = g_strlen (str) + 1;
+          lpszFilter = g_realloc (lpszFilter, (pos + length + 1)
+                                                            * sizeof (CHAR));
+          g_memmove (lpszFilter + pos, str, length * sizeof (CHAR));
+          g_free (str);
+          pos += length;
+          str = g_locale_from_utf8 (ftype[i].ext, -1, NULL, NULL, NULL);
+          length = g_strlen (str) + 1;
+          lpszFilter = g_realloc (lpszFilter, (pos + length + 1)
+                                                            * sizeof (CHAR));
+          g_memmove (lpszFilter + pos, str, length * sizeof (CHAR));
+          g_free (str);
+          pos += length;
+        }
+      lpszFilter[pos] = '\0';
+      szFile[0] = '\0';
+      ofn.lStructSize = sizeof (OPENFILENAMEA);
+      ofn.hwndOwner = GDK_WINDOW_HWND (window->window);
+      ofn.lpstrFilter = lpszFilter;
+      ofn.nFilterIndex = findex - 1;
+      ofn.lpstrCustomFilter = NULL;
+      ofn.lpstrFile = szFile;
+      ofn.nMaxFile = MAX_PATH;
+      ofn.lpstrFileTitle = NULL;
+      ofn.lpstrInitialDir = lpszPath;
+      ofn.lpstrTitle = NULL;
+      ofn.Flags = OFN_HIDEREADONLY | OFN_NOCHANGEDIR | OFN_PATHMUSTEXIST;
+      ofn.lpstrDefExt = NULL;
+      if (GetSaveFileName (&ofn))
+        {
+#  if GTK_CHECK_VERSION(2,6,0)
+          file = g_locale_to_utf8 (szFile, -1, NULL, NULL, NULL);
+#  else /* not GTK_CHECK_VERSION(2,6,0) */
+          file = g_strdup (szFile);
+#  endif /* not GTK_CHECK_VERSION(2,6,0) */
+          findex = ofn.nFilterIndex - 1;
+        }
+      g_free (lpszPath);
+      g_free (lpszFilter);
+# endif /* GLIB_CHECK_VERSION(2,6,0) || ! defined (UNICODE) */
+# if GLIB_CHECK_VERSION(2,6,0)
+    }
+# endif /* GLIB_CHECK_VERSION(2,6,0) */
+#else /* not G_OS_WIN32 */
+  gchar *title;
+  GtkStockItem stock_item;
+  GtkWidget *dialog;
 # if GTK_CHECK_VERSION(2,4,0)
   GtkFileFilter *filter;
+# endif /* GTK_CHECK_VERSION(2,4,0) */
 
-  dialog = gtk_file_chooser_dialog_new (_("Save As"),
+  gtk_stock_lookup (GTK_STOCK_SAVE_AS, &stock_item);
+  title = misc_mnemonic_to_text (stock_item.label);
+# if GTK_CHECK_VERSION(2,4,0)
+  dialog = gtk_file_chooser_dialog_new (title,
                         GTK_WINDOW (window), GTK_FILE_CHOOSER_ACTION_SAVE,
-                        GTK_STOCK_SAVE_AS, GTK_RESPONSE_ACCEPT,
                         GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                        GTK_STOCK_SAVE_AS, GTK_RESPONSE_ACCEPT,
                         NULL);
   if (save_path)
     gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dialog), save_path);
@@ -379,7 +533,7 @@ command_saveas (GtkWidget *widget,
                                                                 "user_data"));
     }
 # else /* not GTK_CHECK_VERSION(2,4,0) */
-  dialog = gtk_file_selection_new (_("Save As"));
+  dialog = gtk_file_selection_new (title);
   if (save_path)
     {
       path = g_strconcat (save_path, G_SEARCHPATH_SEPARATOR_S, NULL);
@@ -391,6 +545,7 @@ command_saveas (GtkWidget *widget,
     file = g_strdup (gtk_file_selection_get_filename
                                                 (GTK_FILE_SELECTION (dialog)));
 # endif /* not GTK_CHECK_VERSION(2,4,0) */
+  g_free (title);
   gtk_widget_destroy (dialog);
 #endif /* not G_OS_WIN32 */
   if (file)
@@ -403,17 +558,23 @@ command_saveas (GtkWidget *widget,
       tmaid = orz_mdi_get_data (ORZ_MDI (mdi), page_num);
       if (tmaid->ft.overwrite && fileio_isfile (file))
         {
-          gchar *utf8str;
+          gchar *filename;
 #ifdef G_OS_WIN32
           GtkWidget *dialog;
 #endif /* G_OS_WIN32 */
 
-          utf8str = g_filename_to_utf8 (file, -1, NULL, NULL, NULL);
+#if GLIB_CHECK_VERSION(2,6,0)
+          filename = g_filename_display_name (file);
+#else /* not GLIB_CHECK_VERSION(2,6,0) */
+          filename = g_filename_to_utf8 (file, -1, NULL, NULL, NULL);
+#endif /* not GLIB_CHECK_VERSION(2,6,0) */
           dialog = gtk_message_dialog_new (GTK_WINDOW (window),
                     GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                     GTK_MESSAGE_INFO, GTK_BUTTONS_YES_NO,
-                    _("%s\nThis file is existed.\n\nOver write?"), utf8str);
-          g_free (utf8str);
+                    _("%s\nThis file is existed.\n\nOver write?"), filename);
+          g_free (filename);
+          g_signal_connect (G_OBJECT (dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
           result = gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_YES;
           gtk_widget_destroy (dialog);
         }
@@ -637,53 +798,8 @@ void
 command_paste (GtkWidget *widget,
                gpointer   user_data)
 {
-  /* ja:Windowsのセレクションの実装があやしいので暫定的処理 */
-#ifdef G_OS_WIN32
-  if (OpenClipboard (GDK_WINDOW_HWND (window->window)))
-    {
-      gchar *text = NULL;
-      HGLOBAL hGlobal;
-
-      if (hGlobal = GetClipboardData (CF_UNICODETEXT))
-        {
-          LPWSTR lpszTextW;
-
-          if (lpszTextW = GlobalLock (hGlobal))
-            text = g_utf16_to_utf8 (lpszTextW, -1, NULL, NULL, NULL);
-          GlobalUnlock (hGlobal);
-        }
-      if (!text && (hGlobal = GetClipboardData (CF_TEXT)))
-        {
-          LPSTR lpszTextA;
-
-          if (lpszTextA = GlobalLock (hGlobal))
-            text = g_locale_to_utf8 (lpszTextA, -1, NULL, NULL, NULL);
-          GlobalUnlock (hGlobal);
-        }
-      CloseClipboard ();
-      if (text)
-        {
-          gint page_num;
-          GdkPoint select;
-          TmaidHistory *d;
-          TmaidWindow *tmaid;
-
-          page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (mdi));
-          tmaid = orz_mdi_get_data (ORZ_MDI (mdi), page_num);
-          select = tmaid->select;
-          d = edit_operation (tmaid, text, g_strlen (text), TRUE, FALSE);
-          g_free (text);
-          d->next = tmaid->undo;
-          tmaid->undo = d;
-          if (delete_list (&tmaid->redo) > 0 || !d->next || select.x >= 0)
-            set_menu_bar (tmaid);
-          orz_mdi_set_edited (ORZ_MDI (mdi), page_num, TRUE);
-        }
-    }
-#else /* not G_OS_WIN32 */
   gtk_selection_convert (window, GDK_SELECTION_CLIPBOARD, atom_targets,
                                                             GDK_CURRENT_TIME);
-#endif /* not G_OS_WIN32 */
 }
 
 
@@ -716,6 +832,8 @@ command_margin (GtkWidget *widget,
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_MESSAGE_INFO, GTK_BUTTONS_YES_NO,
                             _("Return at Right Margin?"));
+  g_signal_connect (G_OBJECT (dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
   result = gtk_dialog_run (GTK_DIALOG (dialog));
   gtk_widget_destroy (dialog);
   if (result == GTK_RESPONSE_YES)
@@ -734,6 +852,8 @@ command_tab (GtkWidget *widget,
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_MESSAGE_INFO, GTK_BUTTONS_YES_NO,
                             _("Convert Tab to Space?"));
+  g_signal_connect (G_OBJECT (dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
   result = gtk_dialog_run (GTK_DIALOG (dialog));
   gtk_widget_destroy (dialog);
   if (result == GTK_RESPONSE_YES)
@@ -904,6 +1024,8 @@ command_next (GtkWidget *widget,
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_MESSAGE_INFO, GTK_BUTTONS_OK,
                             _("'%s' was not fount."), find_text[0]);
+      g_signal_connect (G_OBJECT (dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
       gtk_dialog_run (GTK_DIALOG (dialog));
       gtk_widget_destroy (dialog);
       set_menu_bar (tmaid);
@@ -1063,6 +1185,8 @@ command_replace (GtkWidget *widget,
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_MESSAGE_INFO, GTK_BUTTONS_OK,
                             _("'%s' was not fount."), find_text[0]);
+          g_signal_connect (G_OBJECT (dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
           gtk_dialog_run (GTK_DIALOG (dialog));
           gtk_widget_destroy (dialog);
         }
@@ -1072,6 +1196,8 @@ command_replace (GtkWidget *widget,
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_MESSAGE_INFO, GTK_BUTTONS_OK,
                             _("%d strings were replaced"), count);
+          g_signal_connect (G_OBJECT (dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
           gtk_dialog_run (GTK_DIALOG (dialog));
           gtk_widget_destroy (dialog);
         }
