@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -18,7 +18,6 @@
 */
 #include "charset.h"
 #include "edit.h"
-#include "misc/misc.h"
 
 
 /******************************************************************************
@@ -606,20 +605,13 @@ edit_cpy_sel_mem (TmaidWindow *tmaid,
       length = p->length - st_pos;
       g_memmove (text, p->text + st_pos, length * sizeof (gchar));
       if (!p->margin)
-        {
-          g_memmove (text + length, "\n", sizeof (gchar));
-          length++;
-        }
+        text[length++] = '\n';
       for (i = st.y+  1, p = p->next; i < ed.y && p; i++, p = p->next)
         {
           g_memmove (text + length, p->text, p->length * sizeof (gchar));
           length += p->length;
-          if (!p->margin)
-            {
-              /* ja:改行 */
-              g_memmove (text + length, "\n", sizeof (gchar));
-              length++;
-            }
+          if (!p->margin)/* ja:改行 */
+            text[length++] = '\n';
         }
       g_memmove (text + length, p->text, ed_pos * sizeof (gchar));
     }
@@ -647,7 +639,7 @@ edit_put_mem (TmaidWindow *tmaid,
   data_pos = edit_get_data_pos (tmaid,put->x, put->y, FALSE);
   p = edit_get_line_buf (&tmaid->start, &tmaid->off, put->y);
   if (data_pos <= 0 && p->prev && p->prev->margin && length >= 1
-                                    && !g_memcmp (text, "\n", sizeof(gchar)))
+                                                            && text[0] == '\n')
     {
       /* ja:行頭への挿入で前の行が折り返されており、挿入する文字が改行のとき */
       p = p->prev;
@@ -698,7 +690,7 @@ edit_put_mem (TmaidWindow *tmaid,
                                         tmaid->font_width, tmaid->font_buf);
                 if (tmaid->ft.margin < screen_pos)
                   break;
-                data_pos+=charset_length(text[data_pos]);
+                data_pos += charset_length (text[data_pos]);
               }
             else
               {
@@ -715,7 +707,7 @@ edit_put_mem (TmaidWindow *tmaid,
           p->length += data_pos - i;
           if (length <= data_pos)
             {
-              i=data_pos;
+              i = data_pos;
             }
           else
             {
@@ -727,7 +719,7 @@ edit_put_mem (TmaidWindow *tmaid,
               q->next = p->next;
               p->next = q;
               if (q->next)
-                q->next->prev=q;
+                q->next->prev = q;
               if (data_pos <= length - 1 && text[data_pos] == '\n')
                 {
                   /* ja:改行 */
@@ -761,7 +753,7 @@ edit_put_mem (TmaidWindow *tmaid,
           p->length += data_pos - i;
           if (length <= data_pos)
             {
-              i=data_pos;
+              i = data_pos;
             }
           else
             {
@@ -967,10 +959,10 @@ edit_del_sel_mem (TmaidWindow *tmaid,
             else if (data_pos + charset_length (q->text[data_pos])
                                                                 <= q->length)
               {
-                screen_pos += charset_width (tmaid->layout, 
+                screen_pos += charset_width (tmaid->layout,
                                         q->text + data_pos,
                                         tmaid->font_width, tmaid->font_buf);
-                data_pos+=charset_length(q->text[data_pos]);
+                data_pos += charset_length (q->text[data_pos]);
               }
             else
               {
@@ -994,7 +986,7 @@ edit_del_sel_mem (TmaidWindow *tmaid,
           /* ja:右マージンを下回り擬似改行のとき、次の行とあわせる */
           data_pos = q->length;
           if (p->next)
-            p->next->prev=q;
+            p->next->prev = q;
           q->next = p->next;
           q->length += p->length;
           q->margin = p->margin;
@@ -1057,7 +1049,7 @@ edit_del_sel_mem (TmaidWindow *tmaid,
               q->next = p->next;
               p->next = q;
               if (q->next)
-                q->next->prev=q;
+                q->next->prev = q;
               g_memmove (q->text, p->text + data_pos,
                                                 q->length * sizeof (gchar));
               p->length = data_pos;
@@ -1089,7 +1081,7 @@ edit_del_sel_mem (TmaidWindow *tmaid,
             }
           else
             {
-              p=p->next;
+              p = p->next;
             }
         }
   return result;
