@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -108,6 +108,8 @@ file_open_text (const gchar *file,
                             GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
                             _("Conversion from character encoding"
                             " '%s' to 'UTF-8' is not supported"), charset[i]);
+          g_signal_connect (G_OBJECT (dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
           gtk_dialog_run (GTK_DIALOG (dialog));
           gtk_widget_destroy (dialog);
           for (j = 0; j < ftnum; j++)
@@ -465,8 +467,8 @@ file_open_edit (const gchar *file)
   charset_size (tmaid->layout, &tmaid->font_width, &tmaid->font_height,
                                                             tmaid->font_buf);
   /* ja:プライマリセレクション */
-  gtk_selection_add_targets (tmaid->drawing, GDK_SELECTION_PRIMARY, targets,
-                                sizeof (targets) / sizeof (GtkTargetEntry));
+  gtk_selection_add_targets (tmaid->drawing, GDK_SELECTION_PRIMARY,
+                                            targets, G_N_ELEMENTS (targets));
   g_signal_connect (G_OBJECT (tmaid->drawing), "selection-get",
                                     G_CALLBACK (signal_selection_get), tmaid);
   /* ja:スクロールバー */
@@ -605,6 +607,8 @@ file_save_text (const gchar *file,
                     GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
                     _("Conversion from character encoding"
                     " 'UTF-8' to '%s' is not supported"), tmaid->ft.charset);
+              g_signal_connect (G_OBJECT (dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
               gtk_dialog_run (GTK_DIALOG (dialog));
               gtk_widget_destroy (dialog);
               return FALSE;
@@ -635,6 +639,8 @@ file_save_text (const gchar *file,
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
                             _("Invalid byte sequence in conversion input"));
+                    g_signal_connect (G_OBJECT (dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
                     gtk_dialog_run (GTK_DIALOG (dialog));
                     gtk_widget_destroy (dialog);
                     return FALSE;
@@ -665,6 +671,8 @@ file_save_text (const gchar *file,
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
                             _("Can not open file"));
+          g_signal_connect (G_OBJECT (dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
           gtk_dialog_run (GTK_DIALOG (dialog));
           gtk_widget_destroy (dialog);
           return FALSE;
@@ -684,6 +692,8 @@ file_save_text (const gchar *file,
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
                             _("Can not write"));
+              g_signal_connect (G_OBJECT (dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
               gtk_dialog_run (GTK_DIALOG (dialog));
               gtk_widget_destroy (dialog);
               return FALSE;
@@ -700,6 +710,8 @@ file_save_text (const gchar *file,
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
                             "fileio_close");
+          g_signal_connect (G_OBJECT (dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
           gtk_dialog_run (GTK_DIALOG (dialog));
           gtk_widget_destroy (dialog);
           return FALSE;
