@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,14 +16,12 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
-#include <gdk/gdkkeysyms.h>
 #include "abort.h"
 #include "charset.h"
 #include "edit.h"
 #include "find.h"
 #include "general.h"
 #include "sigfile.h"
-#include "misc/misc.h"
 
 
 gboolean find_arrow = TRUE;                 /* ja:検索の設定 */
@@ -79,7 +77,7 @@ find_operation (TmaidWindow    *tmaid,
 {
   gboolean result;              /* ja:比較の結果,TRUE:同じ,FALSE:異なる */
   gchar *text;
-  gint i,max = 0, sx, sy;
+  gint i, max = 0, sx, sy;
   gint length0, length1 = 0;    /* ja:文字数(バイト単位) */
   gint *buf = NULL, *type = NULL;
   LineBuffer *p, *q;
@@ -112,18 +110,18 @@ find_operation (TmaidWindow    *tmaid,
           edit_cpy_sel_mem (tmaid, &st, &ed, text);
           text[i] = '\0';
           if (ignorecase)   /* ja:大文字/小文字を区別する */
-            result = !g_strcmp (find, text);
+            result = g_strcmp (find, text) == 0;
           else              /* ja:大文字/小文字を区別しない */
-            result = !g_strcasecmp (find, text);
+            result = g_ascii_strcasecmp (find, text) == 0;
           if (result)
-            ed.x=-1;
+            ed.x = -1;
         }
     }
-  if (ed.x<0)
+  if (ed.x < 0)
     {
       if (arrow)
         {
-          ed.x = edit_get_width (tmaid,tmaid->max - 1);
+          ed.x = edit_get_width (tmaid, tmaid->max - 1);
           ed.y = tmaid->max - 1;/* ja:下へ */
         }
       else
@@ -156,9 +154,9 @@ find_operation (TmaidWindow    *tmaid,
                     {
                       g_memmove (text + length1, q->text + data.x,
                                             charset_length (q->text[data.x])
-                                                            * sizeof(gchar));
+                                                            * sizeof (gchar));
                       for (i = 0; i < charset_length (q->text[data.x]); i++)
-                        buf[i + length1] = charset_length (q->text[data.x]);
+                        buf[length1 + i] = charset_length (q->text[data.x]);
                       length1 += charset_length (q->text[data.x]);
                       data.x += charset_length (q->text[data.x]);
                     }
@@ -191,9 +189,9 @@ find_operation (TmaidWindow    *tmaid,
           text[length1] = '\0';
           /* ja:比較 */
           if (ignorecase)   /* ja:大文字/小文字を区別する */
-            result = !g_strcmp (find, text);
+            result = g_strcmp (find, text) == 0;
           else              /* ja:大文字/小文字を区別しない */
-            result = !g_strcasecmp (find, text);
+            result = g_ascii_strcasecmp (find, text) == 0;
           if (result)
             {
               /* ja:一致するとき */
@@ -284,9 +282,9 @@ find_operation (TmaidWindow    *tmaid,
           text[length1] = '\0';
           /* ja:比較 */
           if (ignorecase)   /* ja:大文字/小文字を区別する */
-            result = !g_strcmp (find, text);
+            result = g_strcmp (find, text) == 0;
           else              /* ja:大文字/小文字を区別しない */
-            result = !g_strcasecmp (find, text);
+            result = g_ascii_strcasecmp (find, text) == 0;
           if (result)
             {
               /* ja:一致するとき */
@@ -378,18 +376,6 @@ find_dialog_changed (GtkWidget *widget,
 }
 
 
-/* ja:ESCが押された */
-static gboolean
-find_dialog_key_press (GtkWidget   *widget,
-                       GdkEventKey *event,
-                       gpointer     user_data)
-{
-  if (event->keyval == GDK_Escape)
-    gtk_dialog_response (GTK_DIALOG (widget), GTK_RESPONSE_NONE);
-  return FALSE;
-}
-
-
 /*  ja:検索ダイアログ表示
      fd,検索情報
     RET,TRUE:OK,FALSE:Cancel                                                */
@@ -397,23 +383,28 @@ gboolean
 find_dialog (FindString *fd)
 {
   gboolean result;
+  gchar *title;
   gint i;
 #if ! GTK_CHECK_VERSION(2,4,0)
   GList *glist = NULL;
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
+  GtkStockItem stock_item;
   GtkWidget *dialog, *check, *combo, *radio0, *radio1;
   GtkWidget *frame0, *frame1, *hbox, *tbox, *vbox;
 
   /* ja:メインウインドウ */
+  gtk_stock_lookup (GTK_STOCK_FIND, &stock_item);
+  title = misc_mnemonic_to_text (stock_item.label);
   dialog = gtk_dialog_new_with_buttons
-                            (_("Find"),
+                            (title,
                             GTK_WINDOW (window),
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-                            GTK_STOCK_FIND, GTK_RESPONSE_ACCEPT,
                             GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                            GTK_STOCK_FIND, GTK_RESPONSE_ACCEPT,
                             NULL);
-  g_signal_connect_after (G_OBJECT (dialog), "key-press-event",
-                                    G_CALLBACK (find_dialog_key_press), NULL);
+  g_free (title);
+  g_signal_connect (G_OBJECT (dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
   /* ja:チェックボタン */
   check = gtk_check_button_new_with_mnemonic (_("Enable _Case"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check), fd->ignorecase);
@@ -425,13 +416,13 @@ find_dialog (FindString *fd)
   if (find_num > 0)
     {
       gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
-      gtk_editable_select_region (GTK_EDITABLE (GTK_BIN (combo)->child),
-                                                                        0, -1);
+      gtk_editable_select_region
+                (GTK_EDITABLE (gtk_bin_get_child (GTK_BIN (combo))), 0, -1);
     }
-  g_signal_connect (G_OBJECT (GTK_BIN (combo)->child), "activate",
-                                    G_CALLBACK (find_dialog_activate), dialog);
-  g_signal_connect (G_OBJECT (GTK_BIN (combo)->child), "changed",
-                                    G_CALLBACK (find_dialog_changed), dialog);
+  g_signal_connect (G_OBJECT (gtk_bin_get_child (GTK_BIN (combo))),
+                        "activate", G_CALLBACK (find_dialog_activate), dialog);
+  g_signal_connect (G_OBJECT (gtk_bin_get_child (GTK_BIN (combo))),
+                        "changed", G_CALLBACK (find_dialog_changed), dialog);
 #else /* not GTK_CHECK_VERSION(2,4,0) */
   for (i = 0; i < find_num; i++)
     glist = g_list_append (glist, find_text[i]);
@@ -485,8 +476,9 @@ find_dialog (FindString *fd)
   /* ja:表示 */
 #if GTK_CHECK_VERSION(2,4,0)
   gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT,
-    g_strlen (gtk_entry_get_text (GTK_ENTRY (GTK_BIN (combo)->child))) > 0);
-  gtk_widget_grab_focus (GTK_BIN (combo)->child);
+    g_strlen (gtk_entry_get_text
+                    (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (combo))))) > 0);
+  gtk_widget_grab_focus (gtk_bin_get_child (GTK_BIN (combo)));
 #else /* not GTK_CHECK_VERSION(2,4,0) */
   gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT,
     g_strlen (gtk_entry_get_text (GTK_ENTRY (GTK_COMBO (combo)->entry))) > 0);
@@ -499,7 +491,7 @@ find_dialog (FindString *fd)
     {
 #if GTK_CHECK_VERSION(2,4,0)
       fd->text = g_strdup
-                    (gtk_entry_get_text (GTK_ENTRY (GTK_BIN (combo)->child)));
+        (gtk_entry_get_text (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (combo)))));
 #else /* not GTK_CHECK_VERSION(2,4,0) */
       fd->text = g_strdup
                 (gtk_entry_get_text (GTK_ENTRY (GTK_COMBO (combo)->entry)));
