@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,7 +16,6 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
-#include <gdk/gdkkeysyms.h>
 #include "ftype.h"
 #include "general.h"
 #include "prop.h"
@@ -77,11 +76,9 @@ typedef struct _FileTypeDialog
 {
   gboolean edited;
   gint row;
-  GtkListStore *store;
-  GtkTreeSelection *select;
   GtkWidget *dialog;
   GtkWidget *tview;
-  GtkWidget *button_new;
+  GtkWidget *button_add;
   GtkWidget *button_remove;
   GtkWidget *button_up;
   GtkWidget *button_down;
@@ -103,17 +100,19 @@ ftype_dialog_changed (GtkTreeSelection *select,
 {
   gint i;
   GtkTreeIter iter;
+  GtkTreeModel *model;
 
+  model = gtk_tree_view_get_model (GTK_TREE_VIEW (ftypedlg->tview));
   ftypedlg->row = -1;
-  for (i = 0; gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (ftypedlg->store),
-                                                        &iter, NULL, i); i++)
-    {
-      if (gtk_tree_selection_iter_is_selected (ftypedlg->select, &iter))
+  for (i = 0; gtk_tree_model_iter_nth_child (model, &iter, NULL, i); i++)
+    if (gtk_tree_selection_iter_is_selected (select, &iter))
+      {
         ftypedlg->row = i;
-    }
+        break;
+      }
   if (ftypedlg->row >= 0)
     {
-      gtk_widget_set_sensitive (ftypedlg->button_new, TRUE);
+      gtk_widget_set_sensitive (ftypedlg->button_add, TRUE);
       gtk_widget_set_sensitive (ftypedlg->button_remove, i > 1);
       gtk_widget_set_sensitive (ftypedlg->button_up, ftypedlg->row > 0);
       gtk_widget_set_sensitive (ftypedlg->button_down, ftypedlg->row < i - 1);
@@ -123,7 +122,7 @@ ftype_dialog_changed (GtkTreeSelection *select,
     }
   else
     {
-      gtk_widget_set_sensitive (ftypedlg->button_new, FALSE);
+      gtk_widget_set_sensitive (ftypedlg->button_add, FALSE);
       gtk_widget_set_sensitive (ftypedlg->button_remove, FALSE);
       gtk_widget_set_sensitive (ftypedlg->button_up, FALSE);
       gtk_widget_set_sensitive (ftypedlg->button_down, FALSE);
@@ -136,25 +135,27 @@ ftype_dialog_changed (GtkTreeSelection *select,
 }
 
 
-/* ja:新規 */
+/* ja:追加 */
 static void
-ftype_dialog_clicked_new (GtkWidget      *widget,
+ftype_dialog_clicked_add (GtkWidget      *widget,
                           FileTypeDialog *ftypedlg)
 {
+  GtkListStore *store;
   GtkTreeIter iter;
 
-  if (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (ftypedlg->store),
+  store = GTK_LIST_STORE (gtk_tree_view_get_model
+                                            (GTK_TREE_VIEW (ftypedlg->tview)));
+  if (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (store),
                                                 &iter, NULL, ftypedlg->row))
     {
       FileType *ft_dst, *ft_src;
 
-      gtk_tree_model_get (GTK_TREE_MODEL (ftypedlg->store), &iter,
-                                                            1, &ft_src, -1);
+      gtk_tree_model_get (GTK_TREE_MODEL (store), &iter, 1, &ft_src, -1);
       ft_dst = g_malloc0 (sizeof (FileType));
       ftype_copy (ft_dst, ft_src);
       ft_dst->ft_id = tcount++;
-      gtk_list_store_insert (ftypedlg->store, &iter, ftypedlg->row + 1);
-      gtk_list_store_set (ftypedlg->store, &iter,
+      gtk_list_store_insert (store, &iter, ftypedlg->row + 1);
+      gtk_list_store_set (store, &iter,
                                     0, ft_dst->text, 1, ft_dst, 2, FALSE, -1);
       gtk_dialog_set_response_sensitive (GTK_DIALOG (ftypedlg->dialog),
                                                         GTK_RESPONSE_OK, TRUE);
@@ -168,15 +169,18 @@ static void
 ftype_dialog_clicked_remove (GtkWidget      *widget,
                              FileTypeDialog *ftypedlg)
 {
+  GtkListStore *store;
   GtkTreeIter iter;
 
-  if (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (ftypedlg->store),
+  store = GTK_LIST_STORE (gtk_tree_view_get_model
+                                            (GTK_TREE_VIEW (ftypedlg->tview)));
+  if (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (store),
                                                 &iter, NULL, ftypedlg->row))
     {
       FileType *ft;
 
-      gtk_tree_model_get (GTK_TREE_MODEL (ftypedlg->store), &iter, 1, &ft, -1);
-      gtk_list_store_remove (ftypedlg->store, &iter);
+      gtk_tree_model_get (GTK_TREE_MODEL (store), &iter, 1, &ft, -1);
+      gtk_list_store_remove (store, &iter);
       g_free (ft->text);
       g_free (ft->ext);
       g_free (ft->font_name);
@@ -193,34 +197,37 @@ static void
 ftype_dialog_clicked_up (GtkWidget      *widget,
                          FileTypeDialog *ftypedlg)
 {
+  GtkListStore *store;
   GtkTreeIter iter0, iter1;
+  GtkTreeSelection *select;
 
-  if (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (ftypedlg->store),
+  store = GTK_LIST_STORE (gtk_tree_view_get_model
+                                            (GTK_TREE_VIEW (ftypedlg->tview)));
+  select = gtk_tree_view_get_selection (GTK_TREE_VIEW (ftypedlg->tview));
+  if (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (store),
                                             &iter0, NULL, ftypedlg->row)
-        && gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (ftypedlg->store),
+        && gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (store),
                                             &iter1, NULL, ftypedlg->row - 1))
     {
 #if GTK_CHECK_VERSION(2,2,0)
-      gtk_list_store_swap (ftypedlg->store, &iter0, &iter1);
+      gtk_list_store_swap (store, &iter0, &iter1);
 #else /* not GTK_CHECK_VERSION(2,2,0) */
       gboolean edited0, edited1;
       FileType *ft0, *ft1;
 
-      gtk_tree_model_get (GTK_TREE_MODEL (ftypedlg->store), &iter0,
+      gtk_tree_model_get (GTK_TREE_MODEL (store), &iter0,
                                                     1, &ft0, 2, &edited0, -1);
-      gtk_tree_model_get (GTK_TREE_MODEL (ftypedlg->store), &iter1,
+      gtk_tree_model_get (GTK_TREE_MODEL (store), &iter1,
                                                     1, &ft1, 2, &edited1, -1);
-      gtk_list_store_set (ftypedlg->store, &iter0,
-                                        0, ft1->text, 1, ft1, 2, edited1, -1);
-      gtk_list_store_set (ftypedlg->store, &iter1,
-                                        0, ft0->text, 1, ft0, 2, edited0, -1);
-      gtk_tree_selection_select_iter (ftypedlg->select, &iter1);
+      gtk_list_store_set (store, &iter0, 0, ft1->text, 1, ft1, 2, edited1, -1);
+      gtk_list_store_set (store, &iter1, 0, ft0->text, 1, ft0, 2, edited0, -1);
+      gtk_tree_selection_select_iter (select, &iter1);
       gtk_dialog_set_response_sensitive (GTK_DIALOG (ftypedlg->dialog),
                                                         GTK_RESPONSE_OK, TRUE);
 #endif /* not GTK_CHECK_VERSION(2,2,0) */
       ftypedlg->edited = TRUE;
 #if GTK_CHECK_VERSION(2,2,0)
-      ftype_dialog_changed (ftypedlg->select, ftypedlg);
+      ftype_dialog_changed (select, ftypedlg);
 #endif /* GTK_CHECK_VERSION(2,2,0) */
     }
 }
@@ -231,34 +238,37 @@ static void
 ftype_dialog_clicked_down (GtkWidget      *widget,
                            FileTypeDialog *ftypedlg)
 {
+  GtkListStore *store;
   GtkTreeIter iter0, iter1;
+  GtkTreeSelection *select;
 
-  if (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (ftypedlg->store),
+  store = GTK_LIST_STORE (gtk_tree_view_get_model
+                                            (GTK_TREE_VIEW (ftypedlg->tview)));
+  select = gtk_tree_view_get_selection (GTK_TREE_VIEW (ftypedlg->tview));
+  if (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (store),
                                             &iter0, NULL, ftypedlg->row)
-        && gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (ftypedlg->store),
+        && gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (store),
                                             &iter1, NULL, ftypedlg->row + 1))
     {
 #if GTK_CHECK_VERSION(2,2,0)
-      gtk_list_store_swap (ftypedlg->store, &iter0, &iter1);
+      gtk_list_store_swap (store, &iter0, &iter1);
 #else /* not GTK_CHECK_VERSION(2,2,0) */
       gboolean edited0, edited1;
       FileType *ft0, *ft1;
 
-      gtk_tree_model_get (GTK_TREE_MODEL (ftypedlg->store), &iter0,
+      gtk_tree_model_get (GTK_TREE_MODEL (store), &iter0,
                                                     1, &ft0, 2, &edited0, -1);
-      gtk_tree_model_get (GTK_TREE_MODEL (ftypedlg->store), &iter1,
+      gtk_tree_model_get (GTK_TREE_MODEL (store), &iter1,
                                                     1, &ft1, 2, &edited1, -1);
-      gtk_list_store_set (ftypedlg->store, &iter0,
-                                        0, ft1->text, 1, ft1, 2, edited1, -1);
-      gtk_list_store_set (ftypedlg->store, &iter1,
-                                        0, ft0->text, 1, ft0, 2, edited0, -1);
-      gtk_tree_selection_select_iter (ftypedlg->select, &iter1);
+      gtk_list_store_set (store, &iter0, 0, ft1->text, 1, ft1, 2, edited1, -1);
+      gtk_list_store_set (store, &iter1, 0, ft0->text, 1, ft0, 2, edited0, -1);
+      gtk_tree_selection_select_iter (select, &iter1);
       gtk_dialog_set_response_sensitive (GTK_DIALOG (ftypedlg->dialog),
                                                         GTK_RESPONSE_OK, TRUE);
 #endif /* not GTK_CHECK_VERSION(2,2,0) */
       ftypedlg->edited = TRUE;
 #if GTK_CHECK_VERSION(2,2,0)
-      ftype_dialog_changed (ftypedlg->select, ftypedlg);
+      ftype_dialog_changed (select, ftypedlg);
 #endif /* GTK_CHECK_VERSION(2,2,0) */
     }
 }
@@ -269,18 +279,20 @@ static void
 ftype_dialog_clicked_edit (GtkWidget      *widget,
                            FileTypeDialog *ftypedlg)
 {
+  GtkListStore *store;
   GtkTreeIter iter;
 
-  if (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (ftypedlg->store),
+  store = GTK_LIST_STORE (gtk_tree_view_get_model
+                                            (GTK_TREE_VIEW (ftypedlg->tview)));
+  if (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (store),
                                                 &iter, NULL, ftypedlg->row))
     {
       FileType *ft;
 
-      gtk_tree_model_get (GTK_TREE_MODEL (ftypedlg->store), &iter, 1, &ft, -1);
+      gtk_tree_model_get (GTK_TREE_MODEL (store), &iter, 1, &ft, -1);
       if (property_dialog (GTK_WINDOW (ftypedlg->dialog), ft))
         {
-          gtk_list_store_set (ftypedlg->store, &iter,
-                                            0, ft->text, 1, ft, 2, TRUE, -1);
+          gtk_list_store_set (store, &iter, 0, ft->text, 1, ft, 2, TRUE, -1);
           gtk_dialog_set_response_sensitive (GTK_DIALOG (ftypedlg->dialog),
                                                         GTK_RESPONSE_OK, TRUE);
           ftypedlg->edited = TRUE;
@@ -296,7 +308,8 @@ ftype_dialog_toggled (GtkToggleButton *togglebutton,
 {
   if (gtk_toggle_button_get_active (togglebutton))
     {
-      gtk_tree_selection_unselect_all (ftypedlg->select);
+      gtk_tree_selection_unselect_all (gtk_tree_view_get_selection
+                                            (GTK_TREE_VIEW (ftypedlg->tview)));
       gtk_widget_set_sensitive (ftypedlg->tview, FALSE);
       ftypedlg->row = -1;
     }
@@ -317,13 +330,14 @@ ftype_dialog_destroy (GtkObject      *object,
 {
   gint i;
   GtkTreeIter iter;
+  GtkTreeModel *model;
 
-  for (i = 0; gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (ftypedlg->store),
-                                                        &iter, NULL, i); i++)
+  model = gtk_tree_view_get_model (GTK_TREE_VIEW (ftypedlg->tview));
+  for (i = 0; gtk_tree_model_iter_nth_child (model, &iter, NULL, i); i++)
     {
       FileType *ft;
 
-      gtk_tree_model_get (GTK_TREE_MODEL (ftypedlg->store), &iter, 1, &ft, -1);
+      gtk_tree_model_get (model, &iter, 1, &ft, -1);
       if (ft)
         {
           g_free (ft->text);
@@ -342,7 +356,8 @@ ftype_dialog_drag_end (GtkWidget      *widget,
                        FileTypeDialog *ftypedlg)
 {
   ftypedlg->edited = TRUE;
-  ftype_dialog_changed (ftypedlg->select, ftypedlg);
+  ftype_dialog_changed (gtk_tree_view_get_selection
+                                (GTK_TREE_VIEW (ftypedlg->tview)), ftypedlg);
 }
 
 
@@ -362,9 +377,10 @@ ftype_dialog_button_press (GtkWidget      *widget,
                     (gint)event->x, (gint)event->y, &path, NULL, NULL, NULL))
         {
           GtkTreeIter iter;
+          GtkTreeModel *model;
 
-          if (gtk_tree_model_get_iter (GTK_TREE_MODEL (ftypedlg->store),
-                                                                &iter, path))
+          model = gtk_tree_view_get_model (GTK_TREE_VIEW (ftypedlg->tview));
+          if (gtk_tree_model_get_iter (model, &iter, path))
             {
               ftype_dialog_clicked_edit (widget, ftypedlg);
               result = TRUE;
@@ -376,18 +392,6 @@ ftype_dialog_button_press (GtkWidget      *widget,
 }
 
 
-/* ja:ESCが押された */
-static gboolean
-ftype_dialog_key_press (GtkWidget   *widget,
-                        GdkEventKey *event,
-                        gpointer     user_data)
-{
-  if (event->keyval == GDK_Escape)
-    gtk_dialog_response (GTK_DIALOG (widget), GTK_RESPONSE_NONE);
-  return FALSE;
-}
-
-
 /*  ja:ファイルタイプダイアログを表示する
     parent,親ウインドウ
        ind,TRUE:独立ファイルタイプあり,FALSE:なし
@@ -398,6 +402,8 @@ ftype_dialog (GtkWindow *parent,
 {
   gint i;
   GtkCellRenderer *renderer;
+  GtkListStore *store;
+  GtkTreeSelection *select;
   GtkTreeViewColumn *column;
   GtkWidget *scroll, *hbox, *vbox;
   GtkTargetEntry dnd_entries[1] = {{"GTK_TREE_MODEL_ROW",
@@ -411,17 +417,17 @@ ftype_dialog (GtkWindow *parent,
                             (ind ? _("Associating File Type") : _("File Type"),
                             parent,
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-                            GTK_STOCK_OK, GTK_RESPONSE_OK,
                             GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                            GTK_STOCK_OK, GTK_RESPONSE_OK,
                             NULL);
   gtk_window_set_default_size (GTK_WINDOW (ftypedlg.dialog), 320, 240);
-  g_signal_connect_after (G_OBJECT (ftypedlg.dialog), "key-press-event",
-                                G_CALLBACK (ftype_dialog_key_press), NULL);
+  g_signal_connect (G_OBJECT (ftypedlg.dialog), "key-press-event",
+                                G_CALLBACK (misc_dialog_key_press), NULL);
   g_signal_connect (G_OBJECT (ftypedlg.dialog), "destroy",
                                 G_CALLBACK (ftype_dialog_destroy), &ftypedlg);
   /* ja:ボタン */
-  ftypedlg.button_new = gtk_button_new_from_stock (GTK_STOCK_NEW);
-  ftypedlg.button_remove = gtk_button_new_from_stock (GTK_STOCK_DELETE);
+  ftypedlg.button_add = gtk_button_new_from_stock (GTK_STOCK_ADD);
+  ftypedlg.button_remove = gtk_button_new_from_stock (GTK_STOCK_REMOVE);
   ftypedlg.button_up = gtk_button_new_from_stock (GTK_STOCK_GO_UP);
   ftypedlg.button_down = gtk_button_new_from_stock (GTK_STOCK_GO_DOWN);
 #if GTK_CHECK_VERSION(2,6,0)
@@ -429,8 +435,8 @@ ftype_dialog (GtkWindow *parent,
 #else /* not GTK_CHECK_VERSION(2,6,0) */
   ftypedlg.button_edit = gtk_button_new_with_mnemonic (_("_Edit"));
 #endif /* not GTK_CHECK_VERSION(2,6,0) */
-  g_signal_connect (G_OBJECT (ftypedlg.button_new), "clicked",
-                        G_CALLBACK (ftype_dialog_clicked_new), &ftypedlg);
+  g_signal_connect (G_OBJECT (ftypedlg.button_add), "clicked",
+                        G_CALLBACK (ftype_dialog_clicked_add), &ftypedlg);
   g_signal_connect (G_OBJECT (ftypedlg.button_remove), "clicked",
                         G_CALLBACK (ftype_dialog_clicked_remove), &ftypedlg);
   g_signal_connect (G_OBJECT (ftypedlg.button_up), "clicked",
@@ -439,11 +445,6 @@ ftype_dialog (GtkWindow *parent,
                         G_CALLBACK (ftype_dialog_clicked_down), &ftypedlg);
   g_signal_connect (G_OBJECT (ftypedlg.button_edit), "clicked",
                         G_CALLBACK (ftype_dialog_clicked_edit), &ftypedlg);
-  GTK_WIDGET_SET_FLAGS (ftypedlg.button_new, GTK_CAN_DEFAULT);
-  GTK_WIDGET_SET_FLAGS (ftypedlg.button_remove, GTK_CAN_DEFAULT);
-  GTK_WIDGET_SET_FLAGS (ftypedlg.button_up, GTK_CAN_DEFAULT);
-  GTK_WIDGET_SET_FLAGS (ftypedlg.button_down, GTK_CAN_DEFAULT);
-  GTK_WIDGET_SET_FLAGS (ftypedlg.button_edit, GTK_CAN_DEFAULT);
   /* ja:チェックボタン */
   if (ind)
     {
@@ -457,18 +458,16 @@ ftype_dialog (GtkWindow *parent,
       ftypedlg.check = NULL;
     }
   /* ja:リストボックス */
-  ftypedlg.store = gtk_list_store_new (3,
+  store = gtk_list_store_new (3,
                                 G_TYPE_STRING, G_TYPE_POINTER, G_TYPE_BOOLEAN);
-  ftypedlg.tview = gtk_tree_view_new_with_model
-                                            (GTK_TREE_MODEL (ftypedlg.store));
+  ftypedlg.tview = gtk_tree_view_new_with_model (GTK_TREE_MODEL (store));
   gtk_tree_view_set_enable_search (GTK_TREE_VIEW (ftypedlg.tview), FALSE);
   renderer = gtk_cell_renderer_text_new ();
   column = gtk_tree_view_column_new_with_attributes
                         (_("Registered File Type"), renderer, "text", 0, NULL);
   gtk_tree_view_append_column (GTK_TREE_VIEW (ftypedlg.tview), column);
-  ftypedlg.select = gtk_tree_view_get_selection
-                                            (GTK_TREE_VIEW (ftypedlg.tview));
-  g_signal_connect (G_OBJECT (ftypedlg.select), "changed",
+  select = gtk_tree_view_get_selection (GTK_TREE_VIEW (ftypedlg.tview));
+  g_signal_connect (G_OBJECT (select), "changed",
                                 G_CALLBACK (ftype_dialog_changed), &ftypedlg);
   for (i = 0; i < ftnum; i++)
     {
@@ -477,9 +476,8 @@ ftype_dialog (GtkWindow *parent,
 
       ft = g_malloc0 (sizeof (FileType));
       ftype_copy (ft, ftype + i);
-      gtk_list_store_append (ftypedlg.store, &iter);
-      gtk_list_store_set (ftypedlg.store, &iter,
-                                            0, ft->text, 1, ft, 2, FALSE, -1);
+      gtk_list_store_append (store, &iter);
+      gtk_list_store_set (store, &iter, 0, ft->text, 1, ft, 2, FALSE, -1);
     }
   g_signal_connect (G_OBJECT (ftypedlg.tview), "button-press-event",
                             G_CALLBACK (ftype_dialog_button_press), &ftypedlg);
@@ -503,7 +501,7 @@ ftype_dialog (GtkWindow *parent,
   if (ftypedlg.check)
     gtk_box_pack_start (GTK_BOX (vbox), ftypedlg.check, FALSE, FALSE, 0);
   hbox = gtk_hbox_new (FALSE, SPACING);
-  gtk_box_pack_start (GTK_BOX (hbox), ftypedlg.button_new, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (hbox), ftypedlg.button_add, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (hbox), ftypedlg.button_remove, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (hbox), ftypedlg.button_up, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (hbox), ftypedlg.button_down, FALSE, FALSE, 0);
@@ -512,7 +510,7 @@ ftype_dialog (GtkWindow *parent,
   gtk_container_add (GTK_CONTAINER (GTK_DIALOG (ftypedlg.dialog)->vbox), vbox);
 
   /* ja:表示 */
-  gtk_widget_set_sensitive (ftypedlg.button_new, FALSE);
+  gtk_widget_set_sensitive (ftypedlg.button_add, FALSE);
   gtk_widget_set_sensitive (ftypedlg.button_remove, FALSE);
   gtk_widget_set_sensitive (ftypedlg.button_up, FALSE);
   gtk_widget_set_sensitive (ftypedlg.button_down, FALSE);
@@ -534,21 +532,20 @@ ftype_dialog (GtkWindow *parent,
         }
       g_free (ftype);
       ftype = g_malloc0 (gtk_tree_model_iter_n_children
-                (GTK_TREE_MODEL (ftypedlg.store), NULL) * sizeof (FileType));
+                        (GTK_TREE_MODEL (store), NULL) * sizeof (FileType));
       ftnum = 0;
       for (i = 0; gtk_tree_model_iter_nth_child
-                        (GTK_TREE_MODEL (ftypedlg.store), &iter, NULL, i); i++)
+                                (GTK_TREE_MODEL (store), &iter, NULL, i); i++)
         {
-          gtk_tree_model_get (GTK_TREE_MODEL (ftypedlg.store), &iter,
-                                                                1, &ft, -1);
+          gtk_tree_model_get (GTK_TREE_MODEL (store), &iter, 1, &ft, -1);
           ftype_copy (ftype + ftnum++, ft);
         }
       for (i = 0; gtk_tree_model_iter_nth_child
-                        (GTK_TREE_MODEL (ftypedlg.store), &iter, NULL, i); i++)
+                                (GTK_TREE_MODEL (store), &iter, NULL, i); i++)
         {
           gboolean edited;
 
-          gtk_tree_model_get (GTK_TREE_MODEL (ftypedlg.store), &iter,
+          gtk_tree_model_get (GTK_TREE_MODEL (store), &iter,
                                                     1, &ft, 2, &edited, -1);
           if (edited)
             {
