@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,9 +22,7 @@
 #include "find.h"
 #include "general.h"
 #include "sigfile.h"
-#include "toolbar.h"
 #include "misc/charuty.h"
-#include "misc/misc.h"
 #include "orz/orzmdi.h"
 
 
@@ -181,7 +179,7 @@ set_menu_bar (TmaidWindow *tmaid)
       gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
                                             "paste")), TRUE);
       gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
-                                            "delete")), TRUE);
+                                            "delete")), tmaid->select.x >= 0);
       gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
                                             "undo")), tmaid->undo != NULL);
       gtk_widget_set_sensitive (GTK_WIDGET (misc_find_toolbar (toolbar_entries,
@@ -602,18 +600,25 @@ prompt_close (TmaidWindow *tmaid)
       gint result;
       GtkWidget *dialog;
 
+#if GLIB_CHECK_VERSION(2,6,0)
+      utf8str = g_filename_display_name
+                                    (orz_mdi_get_file (ORZ_MDI (mdi), page));
+#else /* not GLIB_CHECK_VERSION(2,6,0) */
       utf8str = g_filename_to_utf8
                 (orz_mdi_get_file (ORZ_MDI (mdi), page), -1, NULL, NULL, NULL);
+#endif /* not GLIB_CHECK_VERSION(2,6,0) */
       dialog = gtk_message_dialog_new (GTK_WINDOW (window),
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_MESSAGE_INFO, GTK_BUTTONS_NONE,
                             _("File %s was edited.\nSave?"), utf8str);
       g_free (utf8str);
       gtk_dialog_add_buttons (GTK_DIALOG (dialog),
-                                        GTK_STOCK_YES, GTK_RESPONSE_YES,
                                         GTK_STOCK_NO, GTK_RESPONSE_NO,
                                         GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                                        GTK_STOCK_YES, GTK_RESPONSE_YES,
                                         NULL);
+      g_signal_connect (G_OBJECT (dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
       result = gtk_dialog_run (GTK_DIALOG (dialog));
       gtk_widget_destroy (dialog);
       switch (result)
