@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,12 +16,10 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
-#include <gdk/gdkkeysyms.h>
 #include "edit.h"
 #include "general.h"
 #include "jump.h"
 #include "sigfile.h"
-#include "misc/misc.h"
 
 
 /******************************************************************************
@@ -120,18 +118,6 @@ jump_dialog_changed (GtkWidget *widget,
 }
 
 
-/* ja:ESCが押された */
-static gboolean
-jump_dialog_key_press (GtkWidget   *widget,
-                       GdkEventKey *event,
-                       gpointer     user_data)
-{
-  if (event->keyval == GDK_Escape)
-    gtk_dialog_response (GTK_DIALOG (widget), GTK_RESPONSE_NONE);
-  return FALSE;
-}
-
-
 /*  ja:ジャンプダイアログ表示
     jmp,ジャンプ情報
     RET,TRUE:OK,FALSE:Cancel                                                */
@@ -139,19 +125,23 @@ gboolean
 jump_dialog (JumpConfig *jmpcfg)
 {
   gboolean result;
-  gchar *text;
+  gchar *text, *title;
+  GtkStockItem stock_item;
   GtkWidget *dialog, *entry, *vbox;
 
   /* ja:メインウインドウ */
+  gtk_stock_lookup (GTK_STOCK_JUMP_TO, &stock_item);
+  title = misc_mnemonic_to_text (stock_item.label);
   dialog = gtk_dialog_new_with_buttons
-                            (_("Jump"),
+                            (title,
                             GTK_WINDOW (window),
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-                            GTK_STOCK_OK, GTK_RESPONSE_OK,
                             GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                            GTK_STOCK_OK, GTK_RESPONSE_OK,
                             NULL);
-  g_signal_connect_after (G_OBJECT (dialog), "key-press-event",
-                                    G_CALLBACK (jump_dialog_key_press), NULL);
+  g_free (title);
+  g_signal_connect (G_OBJECT (dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
   g_object_set_data (G_OBJECT (dialog), "user_data", jmpcfg);
   /* ja:エントリー */
   entry = gtk_entry_new ();
