@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,7 +16,6 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
-#include <gdk/gdkkeysyms.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include "abort.h"
 #include "charset.h"
@@ -107,6 +106,8 @@ print_out (TmaidWindow *tmaid,
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
                             "CreateCompatibleDC");
+      g_signal_connect (G_OBJECT (dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
       gtk_dialog_run (GTK_DIALOG (dialog));
       gtk_widget_destroy (dialog);
       DeleteDC (prncfg->pd.hDC);
@@ -118,6 +119,8 @@ print_out (TmaidWindow *tmaid,
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
                             "SetAbortProc");
+      g_signal_connect (G_OBJECT (dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
       gtk_dialog_run (GTK_DIALOG (dialog));
       gtk_widget_destroy (dialog);
       DeleteDC (hDC);
@@ -126,9 +129,14 @@ print_out (TmaidWindow *tmaid,
     }
   g_memset (&di, 0, sizeof (DOCINFO));
   di.cbSize = sizeof (DOCINFO);
+#if GLIB_CHECK_VERSION(2,6,0)
+  utf8str = g_filename_display_name (orz_mdi_get_file (ORZ_MDI (mdi),
+                        orz_mdi_get_page_from_data (ORZ_MDI (mdi), tmaid)));
+#else /* not GLIB_CHECK_VERSION(2,6,0) */
   utf8str = g_filename_to_utf8 (orz_mdi_get_file (ORZ_MDI (mdi),
                         orz_mdi_get_page_from_data (ORZ_MDI (mdi), tmaid)),
                                                         -1, NULL, NULL, NULL);
+#endif /* not GLIB_CHECK_VERSION(2,6,0) */
 # ifdef UNICODE
   name = g_utf8_to_utf16 (utf8str, -1, NULL, NULL, NULL);
 # else /* not UNICODE */
@@ -142,6 +150,8 @@ print_out (TmaidWindow *tmaid,
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
                             "StartDoc");
+      g_signal_connect (G_OBJECT (dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
       gtk_dialog_run (GTK_DIALOG (dialog));
       gtk_widget_destroy (dialog);
       DeleteDC (hDC);
@@ -161,6 +171,8 @@ print_out (TmaidWindow *tmaid,
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
                             _("Can not open printer"));
+          g_signal_connect (G_OBJECT (dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
           gtk_dialog_run (GTK_DIALOG (dialog));
           gtk_widget_destroy (dialog);
           return FALSE;
@@ -177,6 +189,8 @@ print_out (TmaidWindow *tmaid,
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
                             _("Can not open file"));
+          g_signal_connect (G_OBJECT (dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
           gtk_dialog_run (GTK_DIALOG (dialog));
           gtk_widget_destroy (dialog);
           return FALSE;
@@ -284,6 +298,8 @@ print_out (TmaidWindow *tmaid,
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
                             "StartPage");
+              g_signal_connect (G_OBJECT (dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
               gtk_dialog_run (GTK_DIALOG (dialog));
               gtk_widget_destroy (dialog);
               goto loop;
@@ -298,6 +314,8 @@ print_out (TmaidWindow *tmaid,
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
                             "StretchBlt");
+              g_signal_connect (G_OBJECT (dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
               gtk_dialog_run (GTK_DIALOG (dialog));
               gtk_widget_destroy (dialog);
               hBitmap = SelectObject (hDC, hBitmap);
@@ -312,6 +330,8 @@ print_out (TmaidWindow *tmaid,
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
                             "EndPage");
+              g_signal_connect (G_OBJECT (dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
               gtk_dialog_run (GTK_DIALOG (dialog));
               gtk_widget_destroy (dialog);
               goto loop;
@@ -390,6 +410,8 @@ print_out (TmaidWindow *tmaid,
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
                             "EndDoc");
+      g_signal_connect (G_OBJECT (dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
       gtk_dialog_run (GTK_DIALOG (dialog));
       gtk_widget_destroy (dialog);
       DeleteDC (hDC);
@@ -402,6 +424,8 @@ print_out (TmaidWindow *tmaid,
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
                             "DeleteDC");
+      g_signal_connect (G_OBJECT (dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
       gtk_dialog_run (GTK_DIALOG (dialog));
       gtk_widget_destroy (dialog);
       DeleteDC (hDC);
@@ -413,6 +437,8 @@ print_out (TmaidWindow *tmaid,
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
                             "DeleteDC");
+      g_signal_connect (G_OBJECT (dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
       gtk_dialog_run (GTK_DIALOG (dialog));
       gtk_widget_destroy (dialog);
       return FALSE;
@@ -642,16 +668,22 @@ static void
 print_dialog_clicked_file (GtkWidget   *widget,
                            PrintDialog *prndlg)
 {
+  gchar *title;
+  GtkStockItem stock_item;
   GtkWidget *dialog;
 # if GTK_CHECK_VERSION(2,4,0)
   gchar *file;
   gint i;
   GtkFileFilter *filter;
+# endif /* GTK_CHECK_VERSION(2,4,0) */
 
-  dialog = gtk_file_chooser_dialog_new (_("Save As"),
+  gtk_stock_lookup (GTK_STOCK_SAVE_AS, &stock_item);
+  title = misc_mnemonic_to_text (stock_item.label);
+# if GTK_CHECK_VERSION(2,4,0)
+  dialog = gtk_file_chooser_dialog_new (title,
                     GTK_WINDOW (prndlg->dialog), GTK_FILE_CHOOSER_ACTION_SAVE,
-                    GTK_STOCK_SAVE_AS, GTK_RESPONSE_ACCEPT,
                     GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                    GTK_STOCK_SAVE_AS, GTK_RESPONSE_ACCEPT,
                     NULL);
   file = g_filename_from_utf8 (gtk_entry_get_text
                     (GTK_ENTRY (prndlg->entry_file)), -1, NULL, NULL, NULL);
@@ -698,7 +730,7 @@ print_dialog_clicked_file (GtkWidget   *widget,
       g_free (file);
     }
 # else /* not GTK_CHECK_VERSION(2,4,0) */
-  dialog = gtk_file_selection_new (_("Save As"));
+  dialog = gtk_file_selection_new (title);
   gtk_file_selection_set_filename (GTK_FILE_SELECTION (dialog),
                         gtk_entry_get_text (GTK_ENTRY (prndlg->entry_file)));
   gtk_file_selection_hide_fileop_buttons (GTK_FILE_SELECTION (dialog));
@@ -706,6 +738,7 @@ print_dialog_clicked_file (GtkWidget   *widget,
     gtk_entry_set_text (GTK_ENTRY (prndlg->entry_file),
                 gtk_file_selection_get_filename (GTK_FILE_SELECTION (dialog)));
 # endif /* not GTK_CHECK_VERSION(2,4,0) */
+  g_free (title);
   gtk_widget_destroy (dialog);
 }
 #endif /* not G_OS_WIN32 */
@@ -757,18 +790,6 @@ print_dialog_activate (GtkWidget   *widget,
 }
 
 
-/* ja:ESCが押された */
-static gboolean
-print_dialog_key_press (GtkWidget   *widget,
-                        GdkEventKey *event,
-                        gpointer     user_data)
-{
-  if (event->keyval == GDK_Escape)
-    gtk_dialog_response (GTK_DIALOG (widget), GTK_RESPONSE_NONE);
-    return FALSE;
-}
-
-
 /*  ja:印刷ダイアログ表示
     prncfg,印刷情報
        RET,TRUE:OK,FALSE:Cancel                                             */
@@ -776,6 +797,8 @@ gboolean
 print_dialog (PrintConfig *prncfg)
 {
   gboolean result;
+  gchar *title;
+  GtkStockItem stock_item;
   GtkWidget *label_column, *hbox0, *hbox1, *vbox;
 #ifndef G_OS_WIN32
   gint i;
@@ -817,15 +840,18 @@ print_dialog (PrintConfig *prncfg)
   prndlg.width = prncfg->width;
   prndlg.height = prncfg->height;
   /* ja:メインウインドウ */
+  gtk_stock_lookup (GTK_STOCK_PRINT, &stock_item);
+  title = misc_mnemonic_to_text (stock_item.label);
   prndlg.dialog = gtk_dialog_new_with_buttons
-                            (_("Print"),
+                            (title,
                             GTK_WINDOW (window),
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-                            GTK_STOCK_PRINT, GTK_RESPONSE_ACCEPT,
                             GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                            GTK_STOCK_PRINT, GTK_RESPONSE_ACCEPT,
                             NULL);
-  g_signal_connect_after (G_OBJECT (prndlg.dialog), "key-press-event",
-                                    G_CALLBACK (print_dialog_key_press), NULL);
+  g_free (title);
+  g_signal_connect (G_OBJECT (prndlg.dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
   /* ja:スピンボタン */
   prndlg.spin_column = gtk_spin_button_new (GTK_ADJUSTMENT (gtk_adjustment_new
                                 (prncfg->column, 1, G_MAXINT, 1, 5, 0)), 0, 0);
