@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,14 +16,12 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
-#include <gdk/gdkkeysyms.h>
 #include "charset.h"
 #include "edit.h"
 #include "ftype.h"
 #include "general.h"
 #include "prop.h"
 #include "sigfile.h"
-#include "misc/misc.h"
 #include "orz/orzcharlist.h"
 #include "orz/orzcharset.h"
 
@@ -147,7 +145,6 @@ typedef struct _PropertyDialog
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
   gint ft_id;
   GdkColor gdk_color[12];
-  GtkListStore *store;
   GtkWidget *dialog;
   GtkWidget *button_color;
 #if GTK_CHECK_VERSION(2,4,0)
@@ -246,8 +243,8 @@ property_dialog_changed (GtkTreeSelection *select,
     {
       GtkTreeIter iter;
 
-      if (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (propdlg->store),
-                                                                &iter, NULL, i)
+      if (gtk_tree_model_iter_nth_child (gtk_tree_view_get_model
+                            (GTK_TREE_VIEW (propdlg->tview)), &iter, NULL, i)
                         && gtk_tree_selection_iter_is_selected (select, &iter))
         {
           row = i;
@@ -265,15 +262,17 @@ property_dialog_clicked_color (GtkWidget      *widget,
 {
   gint i;
   gdouble color[4];
+  GtkListStore *store;
   GtkTreeIter iter;
   GtkWidget *dialog;
 
+  store = GTK_LIST_STORE (gtk_tree_view_get_model
+                                            (GTK_TREE_VIEW (propdlg->tview)));
   dialog = gtk_color_selection_dialog_new (_("Color Configuration"));
   gtk_window_set_transient_for (GTK_WINDOW (dialog),
                                                 GTK_WINDOW (propdlg->dialog));
   for (i = 0; i < 12; i++)
-    if (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (propdlg->store),
-                                                                &iter, NULL, i)
+    if (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (store), &iter, NULL, i)
             && gtk_tree_selection_iter_is_selected
                 (gtk_tree_view_get_selection (GTK_TREE_VIEW (propdlg->tview)),
                                                                         &iter))
@@ -296,7 +295,7 @@ property_dialog_clicked_color (GtkWidget      *widget,
       for (i = 2; i < 18; i++)
         xpm[i] = "XXXXXXXXXXXXXXXXXXXXXXXX";
       for (i = 0; i < 12; i++)
-        if (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (propdlg->store),
+        if (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (store),
                                                                 &iter, NULL, i)
             && gtk_tree_selection_iter_is_selected
                 (gtk_tree_view_get_selection (GTK_TREE_VIEW (propdlg->tview)),
@@ -309,7 +308,7 @@ property_dialog_clicked_color (GtkWidget      *widget,
                                             propdlg->gdk_color[i].red / 256,
                                             propdlg->gdk_color[i].green / 256,
                                             propdlg->gdk_color[i].blue / 256);
-            gtk_list_store_set (propdlg->store, &iter,
+            gtk_list_store_set (store, &iter,
                     0, gdk_pixbuf_new_from_xpm_data ((const char **)xpm), -1);
             g_free (xpm[1]);
           }
@@ -390,8 +389,11 @@ property_dialog_clicked_ftype (GtkWidget      *widget,
     {
       gchar *xpm[18];
       gint i;
+      GtkListStore *store;
       GtkTreeIter iter;
 
+      store = GTK_LIST_STORE (gtk_tree_view_get_model
+                                            (GTK_TREE_VIEW (propdlg->tview)));
       propdlg->ft_id = ftype[pos].ft_id;
       gtk_label_set_text (GTK_LABEL (propdlg->label), ftype[pos].text);
       gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (propdlg->check_gline),
@@ -457,14 +459,14 @@ property_dialog_clicked_ftype (GtkWidget      *widget,
       for (i = 2; i < 18; i++)
         xpm[i] = "XXXXXXXXXXXXXXXXXXXXXXXX";
       for (i = 0; i < 12; i++)
-        if (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (propdlg->store),
+        if (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (store),
                                                             &iter, NULL, i))
           {
             xpm[1] = g_strdup_printf ("X\tc #%02X%02X%02X",
                                             propdlg->gdk_color[i].red / 256,
                                             propdlg->gdk_color[i].green / 256,
                                             propdlg->gdk_color[i].blue / 256);
-            gtk_list_store_set (propdlg->store, &iter,
+            gtk_list_store_set (store, &iter,
                     0, gdk_pixbuf_new_from_xpm_data ((const char **)xpm), -1);
             g_free (xpm[1]);
           }
@@ -503,18 +505,6 @@ property_dialog_activate (GtkWidget      *widget,
 }
 
 
-/* ja:ESCが押された */
-static gboolean
-property_dialog_key_press (GtkWidget   *widget,
-                           GdkEventKey *event,
-                           gpointer     user_data)
-{
-  if (event->keyval == GDK_Escape)
-    gtk_dialog_response (GTK_DIALOG (widget), GTK_RESPONSE_NONE);
-  return FALSE;
-}
-
-
 /*  ja:プロパティダイアログ表示
     parent,親ウインドウ
         ft,ファイルタイプ
@@ -524,12 +514,14 @@ property_dialog (GtkWindow *parent,
                  FileType  *ft)
 {
   gboolean result;
-  gchar *xpm[18];
+  gchar *title, *xpm[18];
   gint i;
 #if ! GTK_CHECK_VERSION(2,4,0)
   GList *glist;
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
+  GtkStockItem stock_item;
   GtkCellRenderer *renderer;
+  GtkListStore *store;
   GtkTreeIter iter;
   GtkTreeSelection *select;
   GtkTreeViewColumn *column;
@@ -548,16 +540,25 @@ property_dialog (GtkWindow *parent,
   PropertyDialog propdlg;
 
   /* ja:メインウインドウ */
+  if (!ft->text || !ft->ext)
+    {
+      gtk_stock_lookup (GTK_STOCK_PROPERTIES, &stock_item);
+      title = misc_mnemonic_to_text (stock_item.label);
+    }
+  else
+    {
+      title = NULL;
+    }
   propdlg.dialog = gtk_dialog_new_with_buttons
-                            (!ft->text || !ft->ext
-                                ? _("Property") : _("Details of File Type"),
+                            (title ? title : _("Details of File Type"),
                             parent,
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-                            GTK_STOCK_OK, GTK_RESPONSE_OK,
                             GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                            GTK_STOCK_OK, GTK_RESPONSE_OK,
                             NULL);
-  g_signal_connect_after (G_OBJECT (propdlg.dialog), "key-press-event",
-                                G_CALLBACK (property_dialog_key_press), NULL);
+  g_free (title);
+  g_signal_connect (G_OBJECT (propdlg.dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
   /* ja:ボタン */
   propdlg.button_color = gtk_button_new_with_label (_("Palette"));
 #if GTK_CHECK_VERSION(2,4,0)
@@ -573,18 +574,12 @@ property_dialog (GtkWindow *parent,
 #else /* not GTK_CHECK_VERSION(2,4,0) */
   g_signal_connect (G_OBJECT (button_font), "clicked",
                         G_CALLBACK (property_dialog_clicked_font), &propdlg);
-#endif /* not GTK_CHECK_VERSION(2,4,0) */
-#if GTK_CHECK_VERSION(2,4,0)
-  GTK_WIDGET_SET_FLAGS (propdlg.button_font, GTK_CAN_DEFAULT);
-#else /* not GTK_CHECK_VERSION(2,4,0) */
-  GTK_WIDGET_SET_FLAGS (button_font, GTK_CAN_DEFAULT);
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
   if (ft->text && ft->ext)
     {
       button_auto = gtk_button_new_with_label (_("Auto Negotiation"));
       g_signal_connect (G_OBJECT (button_auto), "clicked",
                     G_CALLBACK (property_dialog_clicked_charlist), &propdlg);
-      GTK_WIDGET_SET_FLAGS (button_auto, GTK_CAN_DEFAULT);
     }
   else
     {
@@ -596,7 +591,6 @@ property_dialog (GtkWindow *parent,
                 = gtk_button_new_with_mnemonic (_("_Associated File Type"));
       g_signal_connect (G_OBJECT (button_associated), "clicked",
                         G_CALLBACK (property_dialog_clicked_ftype), &propdlg);
-      GTK_WIDGET_SET_FLAGS (button_associated, GTK_CAN_DEFAULT);
     }
   else
     {
@@ -830,9 +824,8 @@ property_dialog (GtkWindow *parent,
   g_signal_connect (G_OBJECT (propdlg.radio_lower), "toggled",
                         G_CALLBACK (property_dialog_ok_sensitive), &propdlg);
   /* ja:リストボックス */
-  propdlg.store = gtk_list_store_new (2, GDK_TYPE_PIXBUF, G_TYPE_STRING);
-  propdlg.tview = gtk_tree_view_new_with_model
-                                            (GTK_TREE_MODEL (propdlg.store));
+  store = gtk_list_store_new (2, GDK_TYPE_PIXBUF, G_TYPE_STRING);
+  propdlg.tview = gtk_tree_view_new_with_model (GTK_TREE_MODEL (store));
   gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (propdlg.tview), FALSE);
   gtk_tree_view_set_enable_search (GTK_TREE_VIEW (propdlg.tview), FALSE);
   renderer = gtk_cell_renderer_pixbuf_new ();
@@ -856,8 +849,8 @@ property_dialog (GtkWindow *parent,
                                                     ft->color[i].red / 256,
                                                     ft->color[i].green / 256,
                                                     ft->color[i].blue / 256);
-      gtk_list_store_append (propdlg.store, &iter);
-      gtk_list_store_set (propdlg.store, &iter,
+      gtk_list_store_append (store, &iter);
+      gtk_list_store_set (store, &iter,
                         0, gdk_pixbuf_new_from_xpm_data ((const char **)xpm),
                         1, _(color_name[i]), -1);
       g_free (xpm[1]);
