@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,7 +16,6 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
-#include <gdk/gdkkeysyms.h>
 #include "reload.h"
 #include "orz/orzcharset.h"
 
@@ -52,18 +51,6 @@ reload_dialog_activate (GtkWidget *widget,
 }
 
 
-/* ja:ESCが押された */
-static gboolean
-reload_dialog_key_press (GtkWidget   *widget,
-                         GdkEventKey *event,
-                         gpointer     user_data)
-{
-  if (event->keyval == GDK_Escape)
-    gtk_dialog_response (GTK_DIALOG (widget), GTK_RESPONSE_NONE);
-  return FALSE;
-}
-
-
 /*  ja:リロードダイアログ表示
       ft,ファイルタイプ
     text,説明文
@@ -73,30 +60,35 @@ reload_dialog (FileType    *ft,
                const gchar *text)
 {
   gboolean result;
+  gchar *title;
   gint i;
 #if ! GTK_CHECK_VERSION(2,4,0)
   GList *glist;
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
+  GtkStockItem stock_item;
   GtkWidget *dialog, *check0, *check1, *combo, *charset, *vbox;
 
   /* ja:メインウインドウ */
+  gtk_stock_lookup (GTK_STOCK_REVERT_TO_SAVED, &stock_item);
+  title = misc_mnemonic_to_text (stock_item.label);
   dialog = gtk_dialog_new_with_buttons
-                            (_("Reload"),
+                            (title,
                             GTK_WINDOW (window),
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             NULL);
-  g_signal_connect_after (G_OBJECT (dialog), "key-press-event",
-                                G_CALLBACK (reload_dialog_key_press), NULL);
+  g_free (title);
+  g_signal_connect (G_OBJECT (dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
   /* ja:ボタン */
   if (text)
     gtk_dialog_add_buttons (GTK_DIALOG (dialog),
-                            GTK_STOCK_YES, GTK_RESPONSE_ACCEPT,
                             GTK_STOCK_NO, GTK_RESPONSE_REJECT,
+                            GTK_STOCK_YES, GTK_RESPONSE_ACCEPT,
                             NULL);
   else
     gtk_dialog_add_buttons (GTK_DIALOG (dialog),
-                            GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
                             GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT,
+                            GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
                             NULL);
   /* ja:チェックボタン */
   check0 = gtk_check_button_new_with_mnemonic
