@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,7 +16,6 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
-#include <gdk/gdkkeysyms.h>
 #include "repinfo.h"
 #include "replace.h"
 
@@ -26,40 +25,32 @@
 * ja:置換情報ダイアログ関数群                                                 *
 *                                                                             *
 ******************************************************************************/
-/* ja:ESCが押された */
-static gboolean
-repinfo_dialog_key_press (GtkWidget   *widget,
-                          GdkEventKey *event,
-                          gpointer     user_data)
-{
-  if (event->keyval == GDK_Escape)
-    gtk_dialog_response (GTK_DIALOG (widget), GTK_RESPONSE_NONE);
-  return FALSE;
-}
-
-
 /*  ja:置換情報ダイアログ表示
      ri,置換情報
     RET,REPLACE_OK,REPLACE_NEXT,REPLACE_ALL,REPLACE_CANCEL                  */
 gint
 repinfo_dialog (ReplaceInfo *ri)
 {
-  gchar *text;
+  gchar *text, *title;
   gint result;
+  GtkStockItem stock_item;
   GtkWidget *dialog, *frame0, *frame1, *hbox, *tbox, *vbox;
 
   /* ja:メインウインドウ */
+  gtk_stock_lookup (GTK_STOCK_FIND_AND_REPLACE, &stock_item);
+  title = misc_mnemonic_to_text (stock_item.label);
   dialog = gtk_dialog_new_with_buttons
-                            (_("Replace Information"),
+                            (title,
                             GTK_WINDOW (window),
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-                            GTK_STOCK_FIND_AND_REPLACE, REPLACE_OK,
+                            GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
                             _("_Next"), REPLACE_NEXT,
                             _("_All Replace"), REPLACE_ALL,
-                            GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                            GTK_STOCK_FIND_AND_REPLACE, REPLACE_OK,
                             NULL);
-  g_signal_connect_after (G_OBJECT (dialog), "key-press-event",
-                                G_CALLBACK (repinfo_dialog_key_press), NULL);
+  g_free (title);
+  g_signal_connect (G_OBJECT (dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
   /* ja:フレームとボックス */
   tbox = gtk_vbox_new (FALSE, SPACING);
   gtk_container_set_border_width (GTK_CONTAINER (tbox), SPACING);
