@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,7 +16,6 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
-#include <gdk/gdkkeysyms.h>
 #include "find.h"
 #include "replace.h"
 
@@ -41,7 +40,8 @@ replace_dialog_activate (GtkWidget *widget,
 
   combo = g_object_get_data (G_OBJECT (dialog), "user_data");
 #if GTK_CHECK_VERSION(2,4,0)
-  if (g_strlen (gtk_entry_get_text (GTK_ENTRY (GTK_BIN (combo)->child))) > 0)
+  if (g_strlen (gtk_entry_get_text
+                        (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (combo))))) > 0)
 #else /* not GTK_CHECK_VERSION(2,4,0) */
   if (g_strlen (gtk_entry_get_text (GTK_ENTRY (GTK_COMBO (combo)->entry))) > 0)
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
@@ -64,18 +64,6 @@ replace_dialog_changed (GtkWidget *widget,
 }
 
 
-/* ja:ESCが押された */
-static gboolean
-replace_dialog_key_press (GtkWidget   *widget,
-                          GdkEventKey *event,
-                          gpointer     user_data)
-{
-  if (event->keyval == GDK_Escape)
-    gtk_dialog_response (GTK_DIALOG (widget), GTK_RESPONSE_NONE);
-  return FALSE;
-}
-
-
 /*  ja:置換ダイアログ表示
      rp,置換情報
     RET,REPLACE_OK,REPLACE_NEXT,REPLACE_ALL,REPLACE_CANCEL                  */
@@ -83,24 +71,29 @@ gint
 replace_dialog (ReplaceString *rp)
 {
   gboolean sensitive;
+  gchar *title;
   gint i, result;
 #if ! GTK_CHECK_VERSION(2,4,0)
   GList *glist = NULL;
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
+  GtkStockItem stock_item;
   GtkWidget *dialog, *check, *combo0, *combo1, *radio0, *radio1;
   GtkWidget *frame0, *frame1, *hbox, *tbox, *vbox;
 
   /* ja:メインウインドウ */
+  gtk_stock_lookup (GTK_STOCK_FIND_AND_REPLACE, &stock_item);
+  title = misc_mnemonic_to_text (stock_item.label);
   dialog = gtk_dialog_new_with_buttons
-                            (_("Replace"),
+                            (title,
                             GTK_WINDOW (window),
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-                            GTK_STOCK_FIND_AND_REPLACE, REPLACE_OK,
-                            _("_All Replace"), REPLACE_ALL,
                             GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                            _("_All Replace"), REPLACE_ALL,
+                            GTK_STOCK_FIND_AND_REPLACE, REPLACE_OK,
                             NULL);
-  g_signal_connect_after (G_OBJECT (dialog), "key-press-event",
-                                G_CALLBACK (replace_dialog_key_press), NULL);
+  g_free (title);
+  g_signal_connect (G_OBJECT (dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
   /* ja:チェックボタン */
   check = gtk_check_button_new_with_mnemonic (_("Enable _Case"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check), rp->ignorecase);
@@ -116,20 +109,20 @@ replace_dialog (ReplaceString *rp)
     {
       gtk_combo_box_set_active (GTK_COMBO_BOX (combo0), 0);
       gtk_editable_select_region
-                            (GTK_EDITABLE (GTK_BIN (combo0)->child), 0, -1);
+                (GTK_EDITABLE (gtk_bin_get_child (GTK_BIN (combo0))), 0, -1);
     }
   if (replace_num > 0)
     {
       gtk_combo_box_set_active (GTK_COMBO_BOX (combo1), 0);
-      gtk_editable_select_region (GTK_EDITABLE (GTK_BIN (combo1)->child),
-                                                                        0, -1);
+      gtk_editable_select_region
+                (GTK_EDITABLE (gtk_bin_get_child (GTK_BIN (combo1))), 0, -1);
     }
-  g_signal_connect (G_OBJECT (GTK_BIN (combo0)->child), "activate",
-                                G_CALLBACK (replace_dialog_activate), dialog);
-  g_signal_connect (G_OBJECT (GTK_BIN (combo1)->child), "activate",
-                                G_CALLBACK (replace_dialog_activate), dialog);
-  g_signal_connect (G_OBJECT (GTK_BIN (combo0)->child), "changed",
-                                G_CALLBACK (replace_dialog_changed), dialog);
+  g_signal_connect (G_OBJECT (gtk_bin_get_child (GTK_BIN (combo0))),
+                    "activate", G_CALLBACK (replace_dialog_activate), dialog);
+  g_signal_connect (G_OBJECT (gtk_bin_get_child (GTK_BIN (combo1))),
+                    "activate", G_CALLBACK (replace_dialog_activate), dialog);
+  g_signal_connect (G_OBJECT (gtk_bin_get_child (GTK_BIN (combo0))),
+                    "changed", G_CALLBACK (replace_dialog_changed), dialog);
 #else /* not GTK_CHECK_VERSION(2,4,0) */
   for (i = 0; i < find_num; i++)
     glist = g_list_append (glist, find_text[i]);
@@ -206,7 +199,7 @@ replace_dialog (ReplaceString *rp)
   /* ja:表示 */
 #if GTK_CHECK_VERSION(2,4,0)
   sensitive = g_strlen (gtk_entry_get_text
-                                    (GTK_ENTRY (GTK_BIN (combo0)->child))) > 0;
+                    (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (combo0))))) > 0;
 #else /* not GTK_CHECK_VERSION(2,4,0) */
   sensitive = g_strlen (gtk_entry_get_text
                                 (GTK_ENTRY (GTK_COMBO (combo0)->entry))) > 0;
@@ -216,7 +209,7 @@ replace_dialog (ReplaceString *rp)
   gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog), REPLACE_ALL,
                                                                     sensitive);
 #if GTK_CHECK_VERSION(2,4,0)
-  gtk_widget_grab_focus (GTK_BIN (combo0)->child);
+  gtk_widget_grab_focus (gtk_bin_get_child (GTK_BIN (combo0)));
 #else /* not GTK_CHECK_VERSION(2,4,0) */
   gtk_widget_grab_focus (GTK_COMBO (combo0)->entry);
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
@@ -227,9 +220,9 @@ replace_dialog (ReplaceString *rp)
     {
 #if GTK_CHECK_VERSION(2,4,0)
       rp->src = g_strdup (gtk_entry_get_text
-                                        (GTK_ENTRY (GTK_BIN (combo0)->child)));
+                        (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (combo0)))));
       rp->dst = g_strdup (gtk_entry_get_text
-                                        (GTK_ENTRY (GTK_BIN (combo1)->child)));
+                        (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (combo1)))));
 #else /* not GTK_CHECK_VERSION(2,4,0) */
       rp->src = g_strdup (gtk_entry_get_text
                                     (GTK_ENTRY (GTK_COMBO (combo0)->entry)));
