@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,12 +22,12 @@
 #include "file.h"
 #include "find.h"
 #include "general.h"
+#include "icons.h"
 #include "jump.h"
 #include "print.h"
 #include "replace.h"
 #include "sigfile.h"
 #include "sigmain.h"
-#include "toolbar.h"
 #include "misc/argument.h"
 #include "misc/charuty.h"
 #include "misc/fileio.h"
@@ -80,71 +80,107 @@ GdkColor system_color[12] = {
     {0, 0x0000, 0x0000, 0x0000}, {0, 0xffff, 0xffff, 0xffff}};
 GtkTargetEntry targets[4] = {       /* ja:Text maidが提供可能なセレクション */
     {"STRING",        0, TARGET_STRING},
-    {"TEXT",          0, TARGET_TEXT}, 
+    {"TEXT",          0, TARGET_TEXT},
     {"COMPOUND_TEXT", 0, TARGET_COMPOUND_TEXT},
     {"UTF8_STRING",   0, TARGET_UTF8}};
 MiscCreateMenuEntry menu_entries[] = {
-{"/",                     NULL,                          NULL,         MISC_CREATE_MENU_BAR,       NULL,             NULL,                    NULL},
-{"/file",                 N_("_File"),                   NULL,         MISC_CREATE_MENU_ITEM,      NULL,             NULL,                    NULL},
-{"/file/",                NULL,                          NULL,         MISC_CREATE_MENU_SHELL,     NULL,             NULL,                    NULL},
-{"/file/new",             N_("_New"),                    "<control>N", MISC_CREATE_MENU_ITEM,      command_new,      NULL,                    NULL},
-{"/file/open",            N_("_Open..."),                "<control>O", MISC_CREATE_MENU_ITEM,      command_open,     NULL,                    NULL},
-{"/file/close",           N_("_Close"),                  "<control>W", MISC_CREATE_MENU_ITEM,      command_close,    NULL,                    NULL},
-{"/file/save",            N_("_Save"),                   "<control>S", MISC_CREATE_MENU_ITEM,      command_save,     NULL,                    NULL},
-{"/file/saveas",          N_("Save _As..."),             NULL,         MISC_CREATE_MENU_ITEM,      command_saveas,   NULL,                    NULL},
-{"/file/reload",          N_("_Reload..."),              "<control>R", MISC_CREATE_MENU_ITEM,      command_reload,   NULL,                    NULL},
-{"/file/sep1",            NULL,                          NULL,         MISC_CREATE_MENU_SEPARATOR, NULL,             NULL,                    NULL},
-{"/file/print",           N_("_Print..."),               "<control>P", MISC_CREATE_MENU_ITEM,      command_print,    NULL,                    NULL},
-{"/file/sep2",            NULL,                          NULL,         MISC_CREATE_MENU_SEPARATOR, NULL,             NULL,                    NULL},
-{"/file/properties",      N_("Propert_ies..."),          "<alt>Return",MISC_CREATE_MENU_ITEM,      command_property, NULL,                    NULL},
-{"/file/sep3",            NULL,                          NULL,         MISC_CREATE_MENU_SEPARATOR, NULL,             NULL,                    NULL},
-{"/file/exit",            N_("E_xit"),                   "<control>Q", MISC_CREATE_MENU_ITEM,      command_exit,     NULL,                    NULL},
-{"/edit",                 N_("_Edit"),                   NULL,         MISC_CREATE_MENU_ITEM,      NULL,             NULL,                    NULL},
-{"/edit/",                NULL,                          NULL,         MISC_CREATE_MENU_SHELL,     NULL,             NULL,                    NULL},
-{"/edit/undo",            N_("_Undo"),                   "<control>Z", MISC_CREATE_MENU_ITEM,      command_undo,     NULL,                    NULL},
-{"/edit/redo",            N_("_Redo"),                   "F4",         MISC_CREATE_MENU_ITEM,      command_redo,     NULL,                    NULL},
-{"/edit/sep1",            NULL,                          NULL,         MISC_CREATE_MENU_SEPARATOR, NULL,             NULL,                    NULL},
-{"/edit/cut",             N_("Cu_t"),                    "<control>X", MISC_CREATE_MENU_ITEM,      command_cut,      NULL,                    NULL},
-{"/edit/copy",            N_("_Copy"),                   "<control>C", MISC_CREATE_MENU_ITEM,      command_copy,     NULL,                    NULL},
-{"/edit/paste",           N_("_Paste"),                  "<control>V", MISC_CREATE_MENU_ITEM,      command_paste,    NULL,                    NULL},
-{"/edit/delete",          N_("De_lete"),                 NULL,         MISC_CREATE_MENU_ITEM,      command_delete,   NULL,                    NULL},
-{"/edit/sep2",            NULL,                          NULL,         MISC_CREATE_MENU_SEPARATOR, NULL,             NULL,                    NULL},
-{"/edit/return",          N_("Return at Right _Margin"), NULL,         MISC_CREATE_MENU_ITEM,      command_margin,   NULL,                    NULL},
-{"/edit/convert",         N_("Convert Ta_b to Space"),   NULL,         MISC_CREATE_MENU_ITEM,      command_tab,      NULL,                    NULL},
-{"/edit/sep3",            NULL,                          NULL,         MISC_CREATE_MENU_SEPARATOR, NULL,             NULL,                    NULL},
-{"/edit/character",       N_("_Character by _Value..."), NULL,         MISC_CREATE_MENU_ITEM,      command_valchr,   NULL,                    NULL},
-{"/edit/jump",            N_("_Jump..."),                "<control>J", MISC_CREATE_MENU_ITEM,      command_jump,     NULL,                    NULL},
-{"/edit/sep4",            NULL,                          NULL,         MISC_CREATE_MENU_SEPARATOR, NULL,             NULL,                    NULL},
-{"/edit/all",             N_("_All"),                    "<control>A", MISC_CREATE_MENU_ITEM,      command_all,      NULL,                    NULL},
-{"/search",               N_("_Search"),                 NULL,         MISC_CREATE_MENU_ITEM,      NULL,             NULL,                    NULL},
-{"/search/",              NULL,                          NULL,         MISC_CREATE_MENU_SHELL,     NULL,             NULL,                    NULL},
-{"/search/find",          N_("_Find..."),                "<control>F", MISC_CREATE_MENU_ITEM,      command_find,     NULL,                    NULL},
-{"/search/next",          N_("_Next"),                   "F3",         MISC_CREATE_MENU_ITEM,      command_next,     GINT_TO_POINTER (TRUE),  NULL},
-{"/search/previous",      N_("_Previous"),               "<shift>F3",  MISC_CREATE_MENU_ITEM,      command_next,     GINT_TO_POINTER (FALSE), NULL},
-{"/search/next",          N_("_Replace..."),             "<control>H", MISC_CREATE_MENU_ITEM,      command_replace,  NULL,                    NULL},
-{"/option",               N_("_Option"),                 NULL,         MISC_CREATE_MENU_ITEM,      NULL,             NULL,                    NULL},
-{"/option/",              NULL,                          NULL,         MISC_CREATE_MENU_SHELL,     NULL,             NULL,                    NULL},
-{"/option/configuration", N_("_Configuration..."),       NULL,         MISC_CREATE_MENU_ITEM,      command_conf,     NULL,                    NULL},
-{"/option/file",          N_("File _Type..."),           NULL,         MISC_CREATE_MENU_ITEM,      command_format,   NULL,                    NULL},
-{"/window",               N_("_Window"),                 NULL,         MISC_CREATE_MENU_ITEM,      NULL,             NULL,                    NULL},
-{"/window/",              NULL,                          NULL,         MISC_CREATE_MENU_SHELL,     NULL,             NULL,                    NULL},
-{"/help",                 N_("_Help"),                   NULL,         MISC_CREATE_MENU_ITEM,      NULL,             NULL,                    NULL},
-{"/help/",                NULL,                          NULL,         MISC_CREATE_MENU_SHELL,     NULL,             NULL,                    NULL},
-{"/help/about",           N_("_About..."),               NULL,         MISC_CREATE_MENU_ITEM,      command_version,  NULL,                    NULL},
-{NULL,                    NULL,                          NULL,         MISC_CREATE_MENU_TERMINAL,  NULL,             NULL,                    NULL}};
+{"/",                   NULL,                          NULL,          NULL,             MISC_CREATE_MENU_BAR,                               NULL,             NULL,                    NULL},
+{"/file",               N_("_File"),                   NULL,          NULL,             MISC_CREATE_MENU_ITEM,                              NULL,             NULL,                    NULL},
+{"/file/",              NULL,                          NULL,          NULL,             MISC_CREATE_MENU_SHELL,                             NULL,             NULL,                    NULL},
+{"/file/new",           GTK_STOCK_NEW,                 NULL,          NULL,             MISC_CREATE_MENU_STOCK,                             command_new,      NULL,                    NULL},
+{"/file/open",          GTK_STOCK_OPEN,                NULL,          NULL,             MISC_CREATE_MENU_STOCK | MISC_CREATE_MENU_ELLIPSIS, command_open,     NULL,                    NULL},
+{"/file/close",         GTK_STOCK_CLOSE,               NULL,          NULL,             MISC_CREATE_MENU_STOCK,                             command_close,    NULL,                    NULL},
+{"/file/save",          GTK_STOCK_SAVE,                NULL,          NULL,             MISC_CREATE_MENU_STOCK,                             command_save,     NULL,                    NULL},
+{"/file/saveas",        GTK_STOCK_SAVE_AS,             NULL,          NULL,             MISC_CREATE_MENU_STOCK | MISC_CREATE_MENU_ELLIPSIS, command_saveas,   NULL,                    NULL},
+{"/file/reload",        GTK_STOCK_REVERT_TO_SAVED,     "<control>R",  NULL,             MISC_CREATE_MENU_STOCK | MISC_CREATE_MENU_ELLIPSIS, command_reload,   NULL,                    NULL},
+{"/file/sep1",          NULL,                          NULL,          NULL,             MISC_CREATE_MENU_SEPARATOR,                         NULL,             NULL,                    NULL},
+{"/file/print",         GTK_STOCK_PRINT,               "<control>P",  NULL,             MISC_CREATE_MENU_STOCK | MISC_CREATE_MENU_ELLIPSIS, command_print,    NULL,                    NULL},
+{"/file/sep2",          NULL,                          NULL,          NULL,             MISC_CREATE_MENU_SEPARATOR,                         NULL,             NULL,                    NULL},
+{"/file/properties",    GTK_STOCK_PROPERTIES,          "<alt>Return", NULL,             MISC_CREATE_MENU_STOCK | MISC_CREATE_MENU_ELLIPSIS, command_property, NULL,                    NULL},
+{"/file/sep3",          NULL,                          NULL,          NULL,             MISC_CREATE_MENU_SEPARATOR,                         NULL,             NULL,                    NULL},
+{"/file/exit",          GTK_STOCK_QUIT,                NULL,          NULL,             MISC_CREATE_MENU_STOCK,                             command_exit,     NULL,                    NULL},
+#if GTK_CHECK_VERSION(2,6,0)
+{"/edit",               GTK_STOCK_EDIT,                NULL,          NULL,             MISC_CREATE_MENU_STOCK | MISC_CREATE_MENU_NOIMAGE,  NULL,             NULL,                    NULL},
+#else /* not GTK_CHECK_VERSION(2,6,0) */
+{"/edit",               N_("_Edit"),                   NULL,          NULL,             MISC_CREATE_MENU_ITEM,                              NULL,             NULL,                    NULL},
+#endif /* not GTK_CHECK_VERSION(2,6,0) */
+{"/edit/",              NULL,                          NULL,          NULL,             MISC_CREATE_MENU_SHELL,                             NULL,             NULL,                    NULL},
+{"/edit/undo",          GTK_STOCK_UNDO,                "<control>Z",  NULL,             MISC_CREATE_MENU_STOCK,                             command_undo,     NULL,                    NULL},
+{"/edit/redo",          GTK_STOCK_REDO,                "F4",          NULL,             MISC_CREATE_MENU_STOCK,                             command_redo,     NULL,                    NULL},
+{"/edit/sep1",          NULL,                          NULL,          NULL,             MISC_CREATE_MENU_SEPARATOR,                         NULL,             NULL,                    NULL},
+{"/edit/cut",           GTK_STOCK_CUT,                 NULL,          NULL,             MISC_CREATE_MENU_STOCK,                             command_cut,      NULL,                    NULL},
+{"/edit/copy",          GTK_STOCK_COPY,                NULL,          NULL,             MISC_CREATE_MENU_STOCK,                             command_copy,     NULL,                    NULL},
+{"/edit/paste",         GTK_STOCK_PASTE,               NULL,          NULL,             MISC_CREATE_MENU_STOCK,                             command_paste,    NULL,                    NULL},
+{"/edit/delete",        GTK_STOCK_DELETE,              NULL,          NULL,             MISC_CREATE_MENU_STOCK,                             command_delete,   NULL,                    NULL},
+{"/edit/sep2",          NULL,                          NULL,          NULL,             MISC_CREATE_MENU_SEPARATOR,                         NULL,             NULL,                    NULL},
+{"/edit/return",        N_("Return at Right _Margin"), NULL,          return16_xpm,     MISC_CREATE_MENU_ITEM,                              command_margin,   NULL,                    NULL},
+{"/edit/tab",           N_("Convert Ta_b to Space"),   NULL,          tab16_xpm,        MISC_CREATE_MENU_ITEM,                              command_tab,      NULL,                    NULL},
+{"/edit/sep3",          NULL,                          NULL,          NULL,             MISC_CREATE_MENU_SEPARATOR,                         NULL,             NULL,                    NULL},
+{"/edit/character",     N_("Character by _Value"),     NULL,          character16_xpm,  MISC_CREATE_MENU_ITEM | MISC_CREATE_MENU_ELLIPSIS,  command_valchr,   NULL,                    NULL},
+{"/edit/jump",          GTK_STOCK_JUMP_TO,             "<control>J",  NULL,             MISC_CREATE_MENU_STOCK,                             command_jump,     NULL,                    NULL},
+{"/edit/sep4",          NULL,                          NULL,          NULL,             MISC_CREATE_MENU_SEPARATOR,                         NULL,             NULL,                    NULL},
+#if GTK_CHECK_VERSION(2,10,0)
+{"/edit/all",           GTK_STOCK_SELECT_ALL,          "<control>A",  NULL,             MISC_CREATE_MENU_ITEM,                              command_all,      NULL,                    NULL},
+#else /* not GTK_CHECK_VERSION(2,10,0) */
+{"/edit/all",           N_("_All"),                    "<control>A",  select_all16_xpm, MISC_CREATE_MENU_ITEM,                              command_all,      NULL,                    NULL},
+#endif /* not GTK_CHECK_VERSION(2,10,0) */
+{"/search",             N_("_Search"),                 NULL,          NULL,             MISC_CREATE_MENU_ITEM,                              NULL,             NULL,                    NULL},
+{"/search/",            NULL,                          NULL,          NULL,             MISC_CREATE_MENU_SHELL,                             NULL,             NULL,                    NULL},
+{"/search/find",        GTK_STOCK_FIND,                NULL,          NULL,             MISC_CREATE_MENU_STOCK | MISC_CREATE_MENU_ELLIPSIS, command_find,     NULL,                    NULL},
+{"/search/next",        N_("_Next"),                   "F3",          next16_xpm,       MISC_CREATE_MENU_ITEM,                              command_next,     GINT_TO_POINTER (TRUE),  NULL},
+{"/search/previous",    N_("_Previous"),               "<shift>F3",   previous16_xpm,   MISC_CREATE_MENU_ITEM,                              command_next,     GINT_TO_POINTER (FALSE), NULL},
+{"/search/next",        GTK_STOCK_FIND_AND_REPLACE,    "<control>H",  NULL,             MISC_CREATE_MENU_STOCK | MISC_CREATE_MENU_ELLIPSIS, command_replace,  NULL,                    NULL},
+{"/option",             N_("_Option"),                 NULL,          NULL,             MISC_CREATE_MENU_ITEM,                              NULL,             NULL,                    NULL},
+{"/option/",            NULL,                          NULL,          NULL,             MISC_CREATE_MENU_SHELL,                             NULL,             NULL,                    NULL},
+{"/option/preferences", GTK_STOCK_PREFERENCES,         NULL,          NULL,             MISC_CREATE_MENU_STOCK | MISC_CREATE_MENU_ELLIPSIS, command_conf,     NULL,                    NULL},
+{"/option/file",        N_("File _Type"),              NULL,          filetype16_xpm,   MISC_CREATE_MENU_ITEM | MISC_CREATE_MENU_ELLIPSIS,  command_format,   NULL,                    NULL},
+{"/window",             N_("_Window"),                 NULL,          NULL,             MISC_CREATE_MENU_ITEM,                              NULL,             NULL,                    NULL},
+{"/window/",            NULL,                          NULL,          NULL,             MISC_CREATE_MENU_SHELL,                             NULL,             NULL,                    NULL},
+{"/help",               GTK_STOCK_HELP,                NULL,          NULL,             MISC_CREATE_MENU_STOCK | MISC_CREATE_MENU_NOIMAGE,  NULL,             NULL,                    NULL},
+{"/help/",              NULL,                          NULL,          NULL,             MISC_CREATE_MENU_SHELL,                             NULL,             NULL,                    NULL},
+#if GTK_CHECK_VERSION(2,6,0)
+{"/help/about",         GTK_STOCK_ABOUT,               NULL,          NULL,             MISC_CREATE_MENU_STOCK,                             command_version,  NULL,                    NULL},
+#else /* not GTK_CHECK_VERSION(2,6,0) */
+{"/help/about",         N_("_About"),                  NULL,          about16_xpm,      MISC_CREATE_MENU_ITEM,                              command_version,  NULL,                    NULL},
+#endif /* not GTK_CHECK_VERSION(2,6,0) */
+{NULL,                  NULL,                          NULL,          NULL,             MISC_CREATE_MENU_TERMINAL,                          NULL,             NULL,                    NULL}};
 MiscCreateMenuEntry popup_entries[] = {
-{"/",                     NULL,                          NULL,         MISC_CREATE_MENU_SHELL,     NULL,             NULL,                    NULL},
-{"/undo",                 N_("_Undo"),                   "<control>Z", MISC_CREATE_MENU_ITEM,      command_undo,     NULL,                    NULL},
-{"/sep1",                 NULL,                          NULL,         MISC_CREATE_MENU_SEPARATOR, NULL,             NULL,                    NULL},
-{"/cut",                  N_("Cu_t"),                    "<control>X", MISC_CREATE_MENU_ITEM,      command_cut,      NULL,                    NULL},
-{"/copy",                 N_("_Copy"),                   "<control>C", MISC_CREATE_MENU_ITEM,      command_copy,     NULL,                    NULL},
-{"/paste",                N_("_Paste"),                  "<control>V", MISC_CREATE_MENU_ITEM,      command_paste,    NULL,                    NULL},
-{"/delete",               N_("De_lete"),                 NULL,         MISC_CREATE_MENU_ITEM,      command_delete,   NULL,                    NULL},
-{"/sep2",                 NULL,                          NULL,         MISC_CREATE_MENU_SEPARATOR, NULL,             NULL,                    NULL},
-{"/all",                  N_("_All"),                    "<control>A", MISC_CREATE_MENU_ITEM,      command_all,      NULL,                    NULL},
-{"/sep3",                 NULL,                          NULL,         MISC_CREATE_MENU_SEPARATOR, NULL,             NULL,                    NULL},
-{"/input",                N_("_Input Methods"),          NULL,         MISC_CREATE_MENU_ITEM,      NULL,             NULL,                    NULL},
-{NULL,                    NULL,                          NULL,         MISC_CREATE_MENU_TERMINAL,  NULL,             NULL,                    NULL}};
+{"/",                   NULL,                          NULL,          NULL,             MISC_CREATE_MENU_SHELL,                             NULL,             NULL,                    NULL},
+{"/undo",               GTK_STOCK_UNDO,                "<control>Z",  NULL,             MISC_CREATE_MENU_STOCK,                             command_undo,     NULL,                    NULL},
+{"/sep1",               NULL,                          NULL,          NULL,             MISC_CREATE_MENU_SEPARATOR,                         NULL,             NULL,                    NULL},
+{"/cut",                GTK_STOCK_CUT,                 NULL,          NULL,             MISC_CREATE_MENU_STOCK,                             command_cut,      NULL,                    NULL},
+{"/copy",               GTK_STOCK_COPY,                NULL,          NULL,             MISC_CREATE_MENU_STOCK,                             command_copy,     NULL,                    NULL},
+{"/paste",              GTK_STOCK_PASTE,               NULL,          NULL,             MISC_CREATE_MENU_STOCK,                             command_paste,    NULL,                    NULL},
+{"/delete",             GTK_STOCK_DELETE,              NULL,          NULL,             MISC_CREATE_MENU_STOCK,                             command_delete,   NULL,                    NULL},
+{"/sep2",               NULL,                          NULL,          NULL,             MISC_CREATE_MENU_SEPARATOR,                         NULL,             NULL,                    NULL},
+#if GTK_CHECK_VERSION(2,10,0)
+{"/all",                GTK_STOCK_SELECT_ALL,          "<control>A",  NULL,             MISC_CREATE_MENU_ITEM,                              command_all,      NULL,                    NULL},
+#else /* not GTK_CHECK_VERSION(2,10,0) */
+{"/all",                N_("_All"),                    "<control>A",  select_all16_xpm, MISC_CREATE_MENU_ITEM,                              command_all,      NULL,                    NULL},
+#endif /* not GTK_CHECK_VERSION(2,10,0) */
+{"/sep3",               NULL,                          NULL,          NULL,             MISC_CREATE_MENU_SEPARATOR,                         NULL,             NULL,                    NULL},
+{"/input",              N_("_Input Methods"),          NULL,          NULL,             MISC_CREATE_MENU_ITEM,                              NULL,             NULL,                    NULL},
+{NULL,                  NULL,                          NULL,          NULL,             MISC_CREATE_MENU_TERMINAL,                          NULL,             NULL,                    NULL}};
+MiscCreateToolbarEntry toolbar_entries[] = {
+{"new",        GTK_STOCK_NEW,              NULL, command_new,      NULL, NULL},
+{"open",       GTK_STOCK_OPEN,             NULL, command_open,     NULL, NULL},
+{"save",       GTK_STOCK_SAVE,             NULL, command_save,     NULL, NULL},
+{"sep1",       NULL,                       NULL, NULL,             NULL, NULL},
+{"properties", GTK_STOCK_PROPERTIES,       NULL, command_property, NULL, NULL},
+{"sep2",       NULL,                       NULL, NULL,             NULL, NULL},
+{"print",      GTK_STOCK_PRINT,            NULL, command_print,    NULL, NULL},
+{"sep3",       NULL,                       NULL, NULL,             NULL, NULL},
+{"cut",        GTK_STOCK_CUT,              NULL, command_cut,      NULL, NULL},
+{"copy",       GTK_STOCK_COPY,             NULL, command_copy,     NULL, NULL},
+{"paste",      GTK_STOCK_PASTE,            NULL, command_paste,    NULL, NULL},
+{"delete",     GTK_STOCK_DELETE,           NULL, command_delete,   NULL, NULL},
+{"sep4",       NULL,                       NULL, NULL,             NULL, NULL},
+{"undo",       GTK_STOCK_UNDO,             NULL, command_undo,     NULL, NULL},
+{"redo",       GTK_STOCK_REDO,             NULL, command_redo,     NULL, NULL},
+{"sep5",       NULL,                       NULL, NULL,             NULL, NULL},
+{"find",       GTK_STOCK_FIND,             NULL, command_find,     NULL, NULL},
+{"replace",    GTK_STOCK_FIND_AND_REPLACE, NULL, command_replace,  NULL, NULL},
+{NULL,         NULL,                       NULL, NULL,             NULL, NULL}};
 
 
 /******************************************************************************
@@ -199,16 +235,16 @@ main (int   argc,
       locale = g_win32_get_package_installation_subdirectory
                             (NULL, argv[0], "lib" G_DIR_SEPARATOR_S "locale");
     }
-# endif /* G_OS_WIN32 */
-# if GLIB_CHECK_VERSION(2,6,0) && defined (G_OS_WIN32)
-#  if GLIB_CHECK_VERSION(2,8,0)
+#  if GLIB_CHECK_VERSION(2,6,0)
+#   if GLIB_CHECK_VERSION(2,8,0)
   temp = g_win32_locale_filename_from_utf8 (locale);
-#  else /* not GLIB_CHECK_VERSION(2,8,0) */
+#   else /* not GLIB_CHECK_VERSION(2,8,0) */
   temp = g_locale_from_utf8 (locale, -1, NULL, NULL, NULL);
-#  endif /* not GLIB_CHECK_VERSION(2,8,0) */
+#   endif /* not GLIB_CHECK_VERSION(2,8,0) */
   g_free (locale);
   locale = temp;
-# endif /* GLIB_CHECK_VERSION(2,6,0) && defined (G_OS_WIN32) */
+#  endif /* GLIB_CHECK_VERSION(2,6,0) */
+# endif /* G_OS_WIN32 */
   bindtextdomain (PACKAGE, locale);
   g_free (locale);
 #endif /* not LOCALEDIR */
@@ -562,6 +598,16 @@ TMAID_COPYRIGHT_NOTICE"\n"
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_window_set_title (GTK_WINDOW (window), "Text maid");
   gtk_window_set_default_size (GTK_WINDOW (window), def_width, def_height);
+  glist = g_list_append (NULL, gdk_pixbuf_new_from_xpm_data (tmaid16_xpm));
+  glist = g_list_append (glist, gdk_pixbuf_new_from_xpm_data (tmaid24_xpm));
+  glist = g_list_append (glist, gdk_pixbuf_new_from_xpm_data (tmaid32_xpm));
+  glist = g_list_append (glist, gdk_pixbuf_new_from_xpm_data (tmaid48_xpm));
+  gtk_window_set_default_icon_list (glist);
+  g_object_unref (G_OBJECT (g_list_nth_data (glist, 0)));
+  g_object_unref (G_OBJECT (g_list_nth_data (glist, 1)));
+  g_object_unref (G_OBJECT (g_list_nth_data (glist, 2)));
+  g_object_unref (G_OBJECT (g_list_nth_data (glist, 3)));
+  g_list_free (glist);
   g_signal_connect (G_OBJECT(window), "delete-event",
                                             G_CALLBACK (signal_delete), NULL);
   g_signal_connect (G_OBJECT (window), "destroy",
@@ -579,9 +625,9 @@ TMAID_COPYRIGHT_NOTICE"\n"
   atom_text = gdk_atom_intern ("TEXT", FALSE);
   atom_utf8 = gdk_atom_intern ("UTF8_STRING", FALSE);
   gtk_selection_add_targets (window, GDK_SELECTION_PRIMARY,
-                        targets, sizeof (targets) / sizeof (GtkTargetEntry));
+                                            targets, G_N_ELEMENTS (targets));
   gtk_selection_add_targets (window, GDK_SELECTION_CLIPBOARD,
-                        targets, sizeof (targets) / sizeof (GtkTargetEntry));
+                                            targets, G_N_ELEMENTS (targets));
   g_signal_connect (G_OBJECT (window), "selection-clear-event",
                                     G_CALLBACK (signal_selection_clear), NULL);
   g_signal_connect (G_OBJECT (window), "selection-get",
@@ -675,7 +721,6 @@ TMAID_COPYRIGHT_NOTICE"\n"
   /* ja:表示 */
   gtk_widget_show_all (window);
   gtk_widget_hide_all (label);
-  gtk_window_set_policy (GTK_WINDOW (window), TRUE, TRUE, TRUE);
 
   /* ja:システム色 */
   style = gtk_widget_get_style (label);
