@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,10 +16,8 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
-#include <gdk/gdkkeysyms.h>
 #include "charset.h"
 #include "valchr.h"
-#include "misc/misc.h"
 
 
 /******************************************************************************
@@ -75,18 +73,6 @@ valchr_dialog_clicked (GtkWidget *widget,
 }
 
 
-/* ja:ESCが押された */
-static gboolean
-valchr_dialog_key_press (GtkWidget   *widget,
-                         GdkEventKey *event,
-                         gpointer     user_data)
-{
-  if (event->keyval == GDK_Escape)
-    gtk_dialog_response (GTK_DIALOG (widget), GTK_RESPONSE_NONE);
-  return FALSE;
-}
-
-
 /*  ja:コード文字入力ダイアログ表示
     valchr,入力文字
        RET,TRUE:OK,FALSE:Cancel                                             */
@@ -102,11 +88,11 @@ valchr_dialog (gunichar *valchr)
                             (_("Character by Value"),
                             GTK_WINDOW (window),
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-                            GTK_STOCK_OK, GTK_RESPONSE_OK,
                             GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                            GTK_STOCK_OK, GTK_RESPONSE_OK,
                             NULL);
-  g_signal_connect_after (G_OBJECT (dialog), "key-press-event",
-                                G_CALLBACK (valchr_dialog_key_press), NULL);
+  g_signal_connect (G_OBJECT (dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
   /* ja:エントリー */
   entry = gtk_entry_new_with_max_length (12);
   text = misc_str_from_val (valchr_default, valchr_base, 0, FALSE);
